/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.14)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../src/ui/mainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.14. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MainWindow_t {
    QByteArrayData data[93];
    char stringdata0[1942];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MainWindow_t qt_meta_stringdata_MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 10), // "MainWindow"
QT_MOC_LITERAL(1, 11, 15), // "DeviceConnected"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 18), // "DeviceDisconnected"
QT_MOC_LITERAL(4, 47, 12), // "PWS_unlocked"
QT_MOC_LITERAL(5, 60, 14), // "PWS_slot_saved"
QT_MOC_LITERAL(6, 75, 7), // "slot_no"
QT_MOC_LITERAL(7, 83, 12), // "DeviceLocked"
QT_MOC_LITERAL(8, 96, 12), // "FactoryReset"
QT_MOC_LITERAL(9, 109, 12), // "PWS_progress"
QT_MOC_LITERAL(10, 122, 1), // "p"
QT_MOC_LITERAL(11, 124, 19), // "OperationInProgress"
QT_MOC_LITERAL(12, 144, 20), // "ShortOperationBegins"
QT_MOC_LITERAL(13, 165, 3), // "msg"
QT_MOC_LITERAL(14, 169, 18), // "ShortOperationEnds"
QT_MOC_LITERAL(15, 188, 14), // "OTP_slot_write"
QT_MOC_LITERAL(16, 203, 6), // "isHOTP"
QT_MOC_LITERAL(17, 210, 9), // "DebugData"
QT_MOC_LITERAL(18, 220, 18), // "LongOperationStart"
QT_MOC_LITERAL(19, 239, 16), // "startAboutDialog"
QT_MOC_LITERAL(20, 256, 15), // "startHelpAction"
QT_MOC_LITERAL(21, 272, 18), // "startConfiguration"
QT_MOC_LITERAL(22, 291, 9), // "changeTab"
QT_MOC_LITERAL(23, 301, 22), // "startConfigurationMain"
QT_MOC_LITERAL(24, 324, 27), // "PWS_Clicked_EnablePWSAccess"
QT_MOC_LITERAL(25, 352, 18), // "factoryResetAction"
QT_MOC_LITERAL(26, 371, 13), // "getTOTPDialog"
QT_MOC_LITERAL(27, 385, 4), // "slot"
QT_MOC_LITERAL(28, 390, 13), // "getHOTPDialog"
QT_MOC_LITERAL(29, 404, 19), // "PWS_ExceClickedSlot"
QT_MOC_LITERAL(30, 424, 4), // "Slot"
QT_MOC_LITERAL(31, 429, 31), // "startStick20ActionChangeUserPIN"
QT_MOC_LITERAL(32, 461, 32), // "startStick20ActionChangeAdminPIN"
QT_MOC_LITERAL(33, 494, 33), // "startStick20ActionChangeUpdat..."
QT_MOC_LITERAL(34, 528, 22), // "startResetUserPassword"
QT_MOC_LITERAL(35, 551, 21), // "startLockDeviceAction"
QT_MOC_LITERAL(36, 573, 20), // "ask_for_confirmation"
QT_MOC_LITERAL(37, 594, 17), // "updateProgressBar"
QT_MOC_LITERAL(38, 612, 1), // "i"
QT_MOC_LITERAL(39, 614, 20), // "show_progress_window"
QT_MOC_LITERAL(40, 635, 15), // "manageStartPage"
QT_MOC_LITERAL(41, 651, 21), // "on_longOperationStart"
QT_MOC_LITERAL(42, 673, 19), // "on_KeepDeviceOnline"
QT_MOC_LITERAL(43, 693, 18), // "on_DeviceConnected"
QT_MOC_LITERAL(44, 712, 21), // "on_DeviceDisconnected"
QT_MOC_LITERAL(45, 734, 22), // "generateComboBoxEntrys"
QT_MOC_LITERAL(46, 757, 37), // "on_enableUserPasswordCheckBox..."
QT_MOC_LITERAL(47, 795, 7), // "checked"
QT_MOC_LITERAL(48, 803, 9), // "resizeMin"
QT_MOC_LITERAL(49, 813, 5), // "ready"
QT_MOC_LITERAL(50, 819, 15), // "checkConnection"
QT_MOC_LITERAL(51, 835, 21), // "storage_check_symlink"
QT_MOC_LITERAL(52, 857, 22), // "on_writeButton_clicked"
QT_MOC_LITERAL(53, 880, 28), // "displayCurrentTotpSlotConfig"
QT_MOC_LITERAL(54, 909, 7), // "uint8_t"
QT_MOC_LITERAL(55, 917, 6), // "slotNo"
QT_MOC_LITERAL(56, 924, 28), // "displayCurrentHotpSlotConfig"
QT_MOC_LITERAL(57, 953, 24), // "displayCurrentSlotConfig"
QT_MOC_LITERAL(58, 978, 27), // "displayCurrentGeneralConfig"
QT_MOC_LITERAL(59, 1006, 35), // "on_slotComboBox_currentIndexC..."
QT_MOC_LITERAL(60, 1042, 5), // "index"
QT_MOC_LITERAL(61, 1048, 25), // "on_hexRadioButton_toggled"
QT_MOC_LITERAL(62, 1074, 28), // "on_base32RadioButton_toggled"
QT_MOC_LITERAL(63, 1103, 26), // "on_setToZeroButton_clicked"
QT_MOC_LITERAL(64, 1130, 28), // "on_setToRandomButton_clicked"
QT_MOC_LITERAL(65, 1159, 37), // "on_enableUserPasswordCheckBox..."
QT_MOC_LITERAL(66, 1197, 35), // "on_writeGeneralConfigButton_c..."
QT_MOC_LITERAL(67, 1233, 15), // "checkTextEdited"
QT_MOC_LITERAL(68, 1249, 23), // "SetupPasswordSafeConfig"
QT_MOC_LITERAL(69, 1273, 22), // "on_eraseButton_clicked"
QT_MOC_LITERAL(70, 1296, 29), // "on_randomSecretButton_clicked"
QT_MOC_LITERAL(71, 1326, 19), // "on_checkBox_toggled"
QT_MOC_LITERAL(72, 1346, 15), // "startStickDebug"
QT_MOC_LITERAL(73, 1362, 18), // "load_settings_page"
QT_MOC_LITERAL(74, 1381, 30), // "on_PWS_ButtonClearSlot_clicked"
QT_MOC_LITERAL(75, 1412, 45), // "on_PWS_ComboBoxSelectSlot_cur..."
QT_MOC_LITERAL(76, 1458, 33), // "on_PWS_CheckBoxHideSecret_tog..."
QT_MOC_LITERAL(77, 1492, 26), // "on_PWS_ButtonClose_pressed"
QT_MOC_LITERAL(78, 1519, 29), // "on_PWS_ButtonCreatePW_clicked"
QT_MOC_LITERAL(79, 1549, 29), // "on_PWS_ButtonSaveSlot_clicked"
QT_MOC_LITERAL(80, 1579, 27), // "on_PWS_ButtonEnable_clicked"
QT_MOC_LITERAL(81, 1607, 30), // "on_counterEdit_editingFinished"
QT_MOC_LITERAL(82, 1638, 24), // "on_radioButton_2_toggled"
QT_MOC_LITERAL(83, 1663, 22), // "on_radioButton_toggled"
QT_MOC_LITERAL(84, 1686, 31), // "on_PWS_EditSlotName_textChanged"
QT_MOC_LITERAL(85, 1718, 4), // "arg1"
QT_MOC_LITERAL(86, 1723, 32), // "on_PWS_EditLoginName_textChanged"
QT_MOC_LITERAL(87, 1756, 31), // "on_PWS_EditPassword_textChanged"
QT_MOC_LITERAL(88, 1788, 28), // "on_btn_writeSettings_clicked"
QT_MOC_LITERAL(89, 1817, 37), // "on_btn_select_debug_file_path..."
QT_MOC_LITERAL(90, 1855, 19), // "on_PWS_Lock_clicked"
QT_MOC_LITERAL(91, 1875, 30), // "on_btn_copyToClipboard_clicked"
QT_MOC_LITERAL(92, 1906, 35) // "on_btn_select_debug_console_c..."

    },
    "MainWindow\0DeviceConnected\0\0"
    "DeviceDisconnected\0PWS_unlocked\0"
    "PWS_slot_saved\0slot_no\0DeviceLocked\0"
    "FactoryReset\0PWS_progress\0p\0"
    "OperationInProgress\0ShortOperationBegins\0"
    "msg\0ShortOperationEnds\0OTP_slot_write\0"
    "isHOTP\0DebugData\0LongOperationStart\0"
    "startAboutDialog\0startHelpAction\0"
    "startConfiguration\0changeTab\0"
    "startConfigurationMain\0"
    "PWS_Clicked_EnablePWSAccess\0"
    "factoryResetAction\0getTOTPDialog\0slot\0"
    "getHOTPDialog\0PWS_ExceClickedSlot\0"
    "Slot\0startStick20ActionChangeUserPIN\0"
    "startStick20ActionChangeAdminPIN\0"
    "startStick20ActionChangeUpdatePIN\0"
    "startResetUserPassword\0startLockDeviceAction\0"
    "ask_for_confirmation\0updateProgressBar\0"
    "i\0show_progress_window\0manageStartPage\0"
    "on_longOperationStart\0on_KeepDeviceOnline\0"
    "on_DeviceConnected\0on_DeviceDisconnected\0"
    "generateComboBoxEntrys\0"
    "on_enableUserPasswordCheckBox_clicked\0"
    "checked\0resizeMin\0ready\0checkConnection\0"
    "storage_check_symlink\0on_writeButton_clicked\0"
    "displayCurrentTotpSlotConfig\0uint8_t\0"
    "slotNo\0displayCurrentHotpSlotConfig\0"
    "displayCurrentSlotConfig\0"
    "displayCurrentGeneralConfig\0"
    "on_slotComboBox_currentIndexChanged\0"
    "index\0on_hexRadioButton_toggled\0"
    "on_base32RadioButton_toggled\0"
    "on_setToZeroButton_clicked\0"
    "on_setToRandomButton_clicked\0"
    "on_enableUserPasswordCheckBox_toggled\0"
    "on_writeGeneralConfigButton_clicked\0"
    "checkTextEdited\0SetupPasswordSafeConfig\0"
    "on_eraseButton_clicked\0"
    "on_randomSecretButton_clicked\0"
    "on_checkBox_toggled\0startStickDebug\0"
    "load_settings_page\0on_PWS_ButtonClearSlot_clicked\0"
    "on_PWS_ComboBoxSelectSlot_currentIndexChanged\0"
    "on_PWS_CheckBoxHideSecret_toggled\0"
    "on_PWS_ButtonClose_pressed\0"
    "on_PWS_ButtonCreatePW_clicked\0"
    "on_PWS_ButtonSaveSlot_clicked\0"
    "on_PWS_ButtonEnable_clicked\0"
    "on_counterEdit_editingFinished\0"
    "on_radioButton_2_toggled\0"
    "on_radioButton_toggled\0"
    "on_PWS_EditSlotName_textChanged\0arg1\0"
    "on_PWS_EditLoginName_textChanged\0"
    "on_PWS_EditPassword_textChanged\0"
    "on_btn_writeSettings_clicked\0"
    "on_btn_select_debug_file_path_clicked\0"
    "on_PWS_Lock_clicked\0on_btn_copyToClipboard_clicked\0"
    "on_btn_select_debug_console_clicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MainWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      79,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      13,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  409,    2, 0x06 /* Public */,
       3,    0,  410,    2, 0x06 /* Public */,
       4,    0,  411,    2, 0x06 /* Public */,
       5,    1,  412,    2, 0x06 /* Public */,
       7,    0,  415,    2, 0x06 /* Public */,
       8,    0,  416,    2, 0x06 /* Public */,
       9,    1,  417,    2, 0x06 /* Public */,
      11,    1,  420,    2, 0x06 /* Public */,
      12,    1,  423,    2, 0x06 /* Public */,
      14,    0,  426,    2, 0x06 /* Public */,
      15,    2,  427,    2, 0x06 /* Public */,
      17,    1,  432,    2, 0x06 /* Public */,
      18,    0,  435,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      19,    0,  436,    2, 0x0a /* Public */,
      20,    0,  437,    2, 0x0a /* Public */,
      21,    1,  438,    2, 0x0a /* Public */,
      21,    0,  441,    2, 0x2a /* Public | MethodCloned */,
      23,    0,  442,    2, 0x0a /* Public */,
      24,    0,  443,    2, 0x0a /* Public */,
      25,    0,  444,    2, 0x0a /* Public */,
      26,    1,  445,    2, 0x0a /* Public */,
      28,    1,  448,    2, 0x0a /* Public */,
      29,    1,  451,    2, 0x0a /* Public */,
      31,    0,  454,    2, 0x0a /* Public */,
      32,    0,  455,    2, 0x0a /* Public */,
      33,    0,  456,    2, 0x0a /* Public */,
      34,    0,  457,    2, 0x0a /* Public */,
      35,    1,  458,    2, 0x0a /* Public */,
      35,    0,  461,    2, 0x2a /* Public | MethodCloned */,
      37,    1,  462,    2, 0x0a /* Public */,
      39,    0,  465,    2, 0x0a /* Public */,
      40,    0,  466,    2, 0x08 /* Private */,
      41,    0,  467,    2, 0x08 /* Private */,
      42,    0,  468,    2, 0x08 /* Private */,
      43,    0,  469,    2, 0x08 /* Private */,
      44,    0,  470,    2, 0x08 /* Private */,
      45,    0,  471,    2, 0x08 /* Private */,
      46,    1,  472,    2, 0x08 /* Private */,
      48,    0,  475,    2, 0x08 /* Private */,
      49,    0,  476,    2, 0x08 /* Private */,
      50,    0,  477,    2, 0x08 /* Private */,
      51,    0,  478,    2, 0x08 /* Private */,
      52,    0,  479,    2, 0x08 /* Private */,
      53,    1,  480,    2, 0x08 /* Private */,
      56,    1,  483,    2, 0x08 /* Private */,
      57,    0,  486,    2, 0x08 /* Private */,
      58,    0,  487,    2, 0x08 /* Private */,
      59,    1,  488,    2, 0x08 /* Private */,
      61,    1,  491,    2, 0x08 /* Private */,
      62,    1,  494,    2, 0x08 /* Private */,
      63,    0,  497,    2, 0x08 /* Private */,
      64,    0,  498,    2, 0x08 /* Private */,
      65,    1,  499,    2, 0x08 /* Private */,
      66,    0,  502,    2, 0x08 /* Private */,
      67,    0,  503,    2, 0x08 /* Private */,
      68,    0,  504,    2, 0x08 /* Private */,
      69,    0,  505,    2, 0x08 /* Private */,
      70,    0,  506,    2, 0x08 /* Private */,
      71,    1,  507,    2, 0x08 /* Private */,
      72,    0,  510,    2, 0x08 /* Private */,
      73,    0,  511,    2, 0x08 /* Private */,
      74,    0,  512,    2, 0x08 /* Private */,
      75,    1,  513,    2, 0x08 /* Private */,
      76,    1,  516,    2, 0x08 /* Private */,
      77,    0,  519,    2, 0x08 /* Private */,
      78,    0,  520,    2, 0x08 /* Private */,
      79,    0,  521,    2, 0x08 /* Private */,
      80,    0,  522,    2, 0x08 /* Private */,
      81,    0,  523,    2, 0x08 /* Private */,
      82,    1,  524,    2, 0x08 /* Private */,
      83,    1,  527,    2, 0x08 /* Private */,
      84,    1,  530,    2, 0x08 /* Private */,
      86,    1,  533,    2, 0x08 /* Private */,
      87,    1,  536,    2, 0x08 /* Private */,
      88,    0,  539,    2, 0x08 /* Private */,
      89,    0,  540,    2, 0x08 /* Private */,
      90,    0,  541,    2, 0x08 /* Private */,
      91,    0,  542,    2, 0x08 /* Private */,
      92,    0,  543,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, QMetaType::QString,   13,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,    6,   16,
    QMetaType::Void, QMetaType::QString,   13,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   22,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Int,
    QMetaType::Void, QMetaType::Int,   27,
    QMetaType::Void, QMetaType::Int,   27,
    QMetaType::Void, QMetaType::Int,   30,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   36,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   38,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   47,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 54,   55,
    QMetaType::Void, 0x80000000 | 54,   55,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   60,
    QMetaType::Void, QMetaType::Bool,   47,
    QMetaType::Void, QMetaType::Bool,   47,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   47,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   47,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   60,
    QMetaType::Void, QMetaType::Bool,   47,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   47,
    QMetaType::Void, QMetaType::Bool,   47,
    QMetaType::Void, QMetaType::QString,   85,
    QMetaType::Void, QMetaType::QString,   85,
    QMetaType::Void, QMetaType::QString,   85,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MainWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->DeviceConnected(); break;
        case 1: _t->DeviceDisconnected(); break;
        case 2: _t->PWS_unlocked(); break;
        case 3: _t->PWS_slot_saved((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->DeviceLocked(); break;
        case 5: _t->FactoryReset(); break;
        case 6: _t->PWS_progress((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->OperationInProgress((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->ShortOperationBegins((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 9: _t->ShortOperationEnds(); break;
        case 10: _t->OTP_slot_write((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 11: _t->DebugData((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 12: _t->LongOperationStart(); break;
        case 13: _t->startAboutDialog(); break;
        case 14: _t->startHelpAction(); break;
        case 15: _t->startConfiguration((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->startConfiguration(); break;
        case 17: _t->startConfigurationMain(); break;
        case 18: _t->PWS_Clicked_EnablePWSAccess(); break;
        case 19: { int _r = _t->factoryResetAction();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->getTOTPDialog((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 21: _t->getHOTPDialog((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 22: _t->PWS_ExceClickedSlot((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 23: _t->startStick20ActionChangeUserPIN(); break;
        case 24: _t->startStick20ActionChangeAdminPIN(); break;
        case 25: _t->startStick20ActionChangeUpdatePIN(); break;
        case 26: _t->startResetUserPassword(); break;
        case 27: _t->startLockDeviceAction((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 28: _t->startLockDeviceAction(); break;
        case 29: _t->updateProgressBar((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 30: _t->show_progress_window(); break;
        case 31: _t->manageStartPage(); break;
        case 32: _t->on_longOperationStart(); break;
        case 33: _t->on_KeepDeviceOnline(); break;
        case 34: _t->on_DeviceConnected(); break;
        case 35: _t->on_DeviceDisconnected(); break;
        case 36: _t->generateComboBoxEntrys(); break;
        case 37: _t->on_enableUserPasswordCheckBox_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 38: _t->resizeMin(); break;
        case 39: _t->ready(); break;
        case 40: _t->checkConnection(); break;
        case 41: _t->storage_check_symlink(); break;
        case 42: _t->on_writeButton_clicked(); break;
        case 43: _t->displayCurrentTotpSlotConfig((*reinterpret_cast< uint8_t(*)>(_a[1]))); break;
        case 44: _t->displayCurrentHotpSlotConfig((*reinterpret_cast< uint8_t(*)>(_a[1]))); break;
        case 45: _t->displayCurrentSlotConfig(); break;
        case 46: _t->displayCurrentGeneralConfig(); break;
        case 47: _t->on_slotComboBox_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 48: _t->on_hexRadioButton_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 49: _t->on_base32RadioButton_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 50: _t->on_setToZeroButton_clicked(); break;
        case 51: _t->on_setToRandomButton_clicked(); break;
        case 52: _t->on_enableUserPasswordCheckBox_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 53: _t->on_writeGeneralConfigButton_clicked(); break;
        case 54: _t->checkTextEdited(); break;
        case 55: _t->SetupPasswordSafeConfig(); break;
        case 56: _t->on_eraseButton_clicked(); break;
        case 57: _t->on_randomSecretButton_clicked(); break;
        case 58: _t->on_checkBox_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 59: _t->startStickDebug(); break;
        case 60: _t->load_settings_page(); break;
        case 61: _t->on_PWS_ButtonClearSlot_clicked(); break;
        case 62: _t->on_PWS_ComboBoxSelectSlot_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 63: _t->on_PWS_CheckBoxHideSecret_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 64: _t->on_PWS_ButtonClose_pressed(); break;
        case 65: _t->on_PWS_ButtonCreatePW_clicked(); break;
        case 66: _t->on_PWS_ButtonSaveSlot_clicked(); break;
        case 67: _t->on_PWS_ButtonEnable_clicked(); break;
        case 68: _t->on_counterEdit_editingFinished(); break;
        case 69: _t->on_radioButton_2_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 70: _t->on_radioButton_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 71: _t->on_PWS_EditSlotName_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 72: _t->on_PWS_EditLoginName_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 73: _t->on_PWS_EditPassword_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 74: _t->on_btn_writeSettings_clicked(); break;
        case 75: _t->on_btn_select_debug_file_path_clicked(); break;
        case 76: _t->on_PWS_Lock_clicked(); break;
        case 77: _t->on_btn_copyToClipboard_clicked(); break;
        case 78: _t->on_btn_select_debug_console_clicked(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (MainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::DeviceConnected)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::DeviceDisconnected)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::PWS_unlocked)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::PWS_slot_saved)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::DeviceLocked)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::FactoryReset)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::PWS_progress)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::OperationInProgress)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::ShortOperationBegins)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::ShortOperationEnds)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)(int , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::OTP_slot_write)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::DebugData)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::LongOperationStart)) {
                *result = 12;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_meta_stringdata_MainWindow.data,
    qt_meta_data_MainWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MainWindow.stringdata0))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 79)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 79;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 79)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 79;
    }
    return _id;
}

// SIGNAL 0
void MainWindow::DeviceConnected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MainWindow::DeviceDisconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MainWindow::PWS_unlocked()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MainWindow::PWS_slot_saved(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void MainWindow::DeviceLocked()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MainWindow::FactoryReset()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MainWindow::PWS_progress(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void MainWindow::OperationInProgress(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void MainWindow::ShortOperationBegins(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void MainWindow::ShortOperationEnds()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void MainWindow::OTP_slot_write(int _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void MainWindow::DebugData(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void MainWindow::LongOperationStart()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
struct qt_meta_stringdata_utf8FieldLengthValidator_t {
    QByteArrayData data[1];
    char stringdata0[25];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_utf8FieldLengthValidator_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_utf8FieldLengthValidator_t qt_meta_stringdata_utf8FieldLengthValidator = {
    {
QT_MOC_LITERAL(0, 0, 24) // "utf8FieldLengthValidator"

    },
    "utf8FieldLengthValidator"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_utf8FieldLengthValidator[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void utf8FieldLengthValidator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject utf8FieldLengthValidator::staticMetaObject = { {
    QMetaObject::SuperData::link<QValidator::staticMetaObject>(),
    qt_meta_stringdata_utf8FieldLengthValidator.data,
    qt_meta_data_utf8FieldLengthValidator,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *utf8FieldLengthValidator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *utf8FieldLengthValidator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_utf8FieldLengthValidator.stringdata0))
        return static_cast<void*>(this);
    return QValidator::qt_metacast(_clname);
}

int utf8FieldLengthValidator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QValidator::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
