/********************************************************************************
** Form generated from reading UI file 'stick20debugdialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STICK20DEBUGDIALOG_H
#define UI_STICK20DEBUGDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_DebugDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QPlainTextEdit *TextGUI;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *DebugDialog)
    {
        if (DebugDialog->objectName().isEmpty())
            DebugDialog->setObjectName(QString::fromUtf8("DebugDialog"));
        DebugDialog->resize(793, 789);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/new/icon_NK.svg"), QSize(), QIcon::Normal, QIcon::Off);
        DebugDialog->setWindowIcon(icon);
        verticalLayout_2 = new QVBoxLayout(DebugDialog);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        TextGUI = new QPlainTextEdit(DebugDialog);
        TextGUI->setObjectName(QString::fromUtf8("TextGUI"));
        QFont font;
        font.setFamily(QString::fromUtf8("Courier New"));
        TextGUI->setFont(font);
        TextGUI->setLineWrapMode(QPlainTextEdit::NoWrap);
        TextGUI->setReadOnly(true);
        TextGUI->setPlainText(QString::fromUtf8(""));

        verticalLayout->addWidget(TextGUI);

        buttonBox = new QDialogButtonBox(DebugDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        verticalLayout_2->addLayout(verticalLayout);


        retranslateUi(DebugDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), DebugDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), DebugDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(DebugDialog);
    } // setupUi

    void retranslateUi(QDialog *DebugDialog)
    {
        DebugDialog->setWindowTitle(QCoreApplication::translate("DebugDialog", "Debug Log", nullptr));
        TextGUI->setPlaceholderText(QCoreApplication::translate("DebugDialog", "Debug Log", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DebugDialog: public Ui_DebugDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_STICK20DEBUGDIALOG_H
