/********************************************************************************
** Form generated from reading UI file 'stick20changepassworddialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STICK20CHANGEPASSWORDDIALOG_H
#define UI_STICK20CHANGEPASSWORDDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_DialogChangePassword
{
public:
    QVBoxLayout *verticalLayout;
    QFrame *frame;
    QVBoxLayout *verticalLayout_4;
    QFormLayout *formLayout;
    QLabel *label_2;
    QLineEdit *lineEdit_OldPW;
    QLabel *label_3;
    QLineEdit *lineEdit_NewPW_1;
    QLabel *label_4;
    QLineEdit *lineEdit_NewPW_2;
    QCheckBox *checkBox;
    QLabel *label_additional_information;
    QHBoxLayout *horizontalLayout;
    QLabel *retryCountLabel;
    QLabel *retryCount;
    QSpacerItem *verticalSpacer;
    QFrame *line;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *DialogChangePassword)
    {
        if (DialogChangePassword->objectName().isEmpty())
            DialogChangePassword->setObjectName(QString::fromUtf8("DialogChangePassword"));
        DialogChangePassword->resize(420, 369);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(DialogChangePassword->sizePolicy().hasHeightForWidth());
        DialogChangePassword->setSizePolicy(sizePolicy);
        DialogChangePassword->setMinimumSize(QSize(420, 300));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/new/icon_NK.svg"), QSize(), QIcon::Normal, QIcon::Off);
        DialogChangePassword->setWindowIcon(icon);
        verticalLayout = new QVBoxLayout(DialogChangePassword);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        frame = new QFrame(DialogChangePassword);
        frame->setObjectName(QString::fromUtf8("frame"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(frame->sizePolicy().hasHeightForWidth());
        frame->setSizePolicy(sizePolicy1);
        frame->setAutoFillBackground(false);
        frame->setFrameShape(QFrame::NoFrame);
        frame->setFrameShadow(QFrame::Plain);
        verticalLayout_4 = new QVBoxLayout(frame);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        formLayout = new QFormLayout();
        formLayout->setObjectName(QString::fromUtf8("formLayout"));
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        label_2 = new QLabel(frame);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setText(QString::fromUtf8("Old PIN"));
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::LabelRole, label_2);

        lineEdit_OldPW = new QLineEdit(frame);
        lineEdit_OldPW->setObjectName(QString::fromUtf8("lineEdit_OldPW"));
        QSizePolicy sizePolicy2(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(lineEdit_OldPW->sizePolicy().hasHeightForWidth());
        lineEdit_OldPW->setSizePolicy(sizePolicy2);

        formLayout->setWidget(0, QFormLayout::FieldRole, lineEdit_OldPW);

        label_3 = new QLabel(frame);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setText(QString::fromUtf8("New PIN"));
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(1, QFormLayout::LabelRole, label_3);

        lineEdit_NewPW_1 = new QLineEdit(frame);
        lineEdit_NewPW_1->setObjectName(QString::fromUtf8("lineEdit_NewPW_1"));
        sizePolicy2.setHeightForWidth(lineEdit_NewPW_1->sizePolicy().hasHeightForWidth());
        lineEdit_NewPW_1->setSizePolicy(sizePolicy2);

        formLayout->setWidget(1, QFormLayout::FieldRole, lineEdit_NewPW_1);

        label_4 = new QLabel(frame);
        label_4->setObjectName(QString::fromUtf8("label_4"));
        label_4->setText(QString::fromUtf8("New PIN"));
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(2, QFormLayout::LabelRole, label_4);

        lineEdit_NewPW_2 = new QLineEdit(frame);
        lineEdit_NewPW_2->setObjectName(QString::fromUtf8("lineEdit_NewPW_2"));
        sizePolicy2.setHeightForWidth(lineEdit_NewPW_2->sizePolicy().hasHeightForWidth());
        lineEdit_NewPW_2->setSizePolicy(sizePolicy2);

        formLayout->setWidget(2, QFormLayout::FieldRole, lineEdit_NewPW_2);

        checkBox = new QCheckBox(frame);
        checkBox->setObjectName(QString::fromUtf8("checkBox"));
        QSizePolicy sizePolicy3(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(checkBox->sizePolicy().hasHeightForWidth());
        checkBox->setSizePolicy(sizePolicy3);

        formLayout->setWidget(3, QFormLayout::FieldRole, checkBox);


        verticalLayout_4->addLayout(formLayout);

        label_additional_information = new QLabel(frame);
        label_additional_information->setObjectName(QString::fromUtf8("label_additional_information"));
        QSizePolicy sizePolicy4(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(label_additional_information->sizePolicy().hasHeightForWidth());
        label_additional_information->setSizePolicy(sizePolicy4);
        label_additional_information->setMouseTracking(true);
        label_additional_information->setFocusPolicy(Qt::StrongFocus);
        label_additional_information->setScaledContents(false);
        label_additional_information->setWordWrap(true);

        verticalLayout_4->addWidget(label_additional_information);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        retryCountLabel = new QLabel(frame);
        retryCountLabel->setObjectName(QString::fromUtf8("retryCountLabel"));

        horizontalLayout->addWidget(retryCountLabel);

        retryCount = new QLabel(frame);
        retryCount->setObjectName(QString::fromUtf8("retryCount"));
        retryCount->setFocusPolicy(Qt::StrongFocus);
        retryCount->setText(QString::fromUtf8("3"));

        horizontalLayout->addWidget(retryCount);


        verticalLayout_4->addLayout(horizontalLayout);


        verticalLayout->addWidget(frame);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        line = new QFrame(DialogChangePassword);
        line->setObjectName(QString::fromUtf8("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        verticalLayout->addWidget(line);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        buttonBox = new QDialogButtonBox(DialogChangePassword);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        horizontalLayout_2->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout_2);

        QWidget::setTabOrder(lineEdit_OldPW, lineEdit_NewPW_1);
        QWidget::setTabOrder(lineEdit_NewPW_1, lineEdit_NewPW_2);
        QWidget::setTabOrder(lineEdit_NewPW_2, checkBox);
        QWidget::setTabOrder(checkBox, label_additional_information);
        QWidget::setTabOrder(label_additional_information, retryCount);

        retranslateUi(DialogChangePassword);
        QObject::connect(buttonBox, SIGNAL(accepted()), DialogChangePassword, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), DialogChangePassword, SLOT(reject()));

        QMetaObject::connectSlotsByName(DialogChangePassword);
    } // setupUi

    void retranslateUi(QDialog *DialogChangePassword)
    {
        DialogChangePassword->setWindowTitle(QCoreApplication::translate("DialogChangePassword", "Change user PIN", nullptr));
#if QT_CONFIG(accessibility)
        lineEdit_OldPW->setAccessibleName(QCoreApplication::translate("DialogChangePassword", "Current PIN or password", nullptr));
#endif // QT_CONFIG(accessibility)
#if QT_CONFIG(accessibility)
        lineEdit_NewPW_1->setAccessibleName(QCoreApplication::translate("DialogChangePassword", "New PIN or password", nullptr));
#endif // QT_CONFIG(accessibility)
#if QT_CONFIG(accessibility)
        lineEdit_NewPW_2->setAccessibleName(QCoreApplication::translate("DialogChangePassword", "New PIN or password", nullptr));
#endif // QT_CONFIG(accessibility)
        checkBox->setText(QCoreApplication::translate("DialogChangePassword", "Show PIN", nullptr));
        label_additional_information->setText(QCoreApplication::translate("DialogChangePassword", "<html><head/><body><p><span style=\" font-style:italic;\">Nitrokey prevents against brute force password guessing attacks by allowing a maximum of 3 incorrect PIN attempts. Therefore a PIN of %1 digits is sufficient. The PIN must be between %1 and %2 characters.</span></p></body></html>", nullptr));
        retryCountLabel->setText(QCoreApplication::translate("DialogChangePassword", "Retry count left:", nullptr));
#if QT_CONFIG(accessibility)
        retryCount->setAccessibleName(QString());
#endif // QT_CONFIG(accessibility)
#if QT_CONFIG(accessibility)
        retryCount->setAccessibleDescription(QCoreApplication::translate("DialogChangePassword", "Retry count left:", nullptr));
#endif // QT_CONFIG(accessibility)
    } // retranslateUi

};

namespace Ui {
    class DialogChangePassword: public Ui_DialogChangePassword {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_STICK20CHANGEPASSWORDDIALOG_H
