/********************************************************************************
** Form generated from reading UI file 'aboutdialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ABOUTDIALOG_H
#define UI_ABOUTDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_AboutDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QFrame *frame;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_3;
    QLabel *IconLabel;
    QVBoxLayout *verticalLayout_7;
    QLabel *label_7;
    QHBoxLayout *horizontalLayout_5;
    QLabel *info_icon;
    QLabel *label_6;
    QSpacerItem *horizontalSpacer_3;
    QFrame *line_2;
    QHBoxLayout *horizontalLayout_7;
    QFormLayout *formLayout_2;
    QLabel *label_3;
    QLabel *VersionLabel;
    QSpacerItem *horizontalSpacer_2;
    QFormLayout *formLayout_3;
    QLabel *label_4;
    QLabel *firmwareLabel;
    QSpacerItem *horizontalSpacer_8;
    QFormLayout *formLayout_4;
    QLabel *label_5;
    QLabel *serialEdit;
    QFrame *line_3;
    QFrame *frame_2;
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QFrame *line;
    QHBoxLayout *horizontalLayout_6;
    QFormLayout *storage_info;
    QLabel *label_8;
    QLabel *sd_id_label;
    QLabel *label_9;
    QLabel *unencrypted_volume_label;
    QLabel *label_10;
    QLabel *encrypted_volume_label;
    QLabel *label_11;
    QLabel *hidden_volume_label;
    QLabel *static_storage_info;
    QSpacerItem *verticalSpacer_3;
    QLabel *l_storage_capacity;
    QSpacerItem *horizontalSpacer_6;
    QFormLayout *formLayout;
    QLabel *label1;
    QLabel *label2;
    QLabel *admin_retry_label;
    QLabel *user_retry_label;
    QLabel *label_2;
    QLabel *newsd_label;
    QLabel *not_erased_sd_label;
    QLabel *DeviceStatusLabel;
    QHBoxLayout *horizontalLayout_4;
    QLabel *warning_sign;
    QLabel *label_12;
    QSpacerItem *horizontalSpacer_4;
    QLabel *label_13;
    QSpacerItem *horizontalSpacer_5;
    QSpacerItem *verticalSpacer;
    QSpacerItem *verticalSpacer_4;
    QLabel *AboutLabel_2;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *btn_3rdparty;
    QPushButton *ButtonStickStatus;
    QPushButton *ButtonOK;

    void setupUi(QDialog *AboutDialog)
    {
        if (AboutDialog->objectName().isEmpty())
            AboutDialog->setObjectName(QString::fromUtf8("AboutDialog"));
        AboutDialog->resize(642, 589);
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(AboutDialog->sizePolicy().hasHeightForWidth());
        AboutDialog->setSizePolicy(sizePolicy);
        AboutDialog->setFocusPolicy(Qt::NoFocus);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/new/icon_NK.svg"), QSize(), QIcon::Normal, QIcon::Off);
        AboutDialog->setWindowIcon(icon);
        AboutDialog->setAutoFillBackground(false);
        verticalLayout_2 = new QVBoxLayout(AboutDialog);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        frame = new QFrame(AboutDialog);
        frame->setObjectName(QString::fromUtf8("frame"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(frame->sizePolicy().hasHeightForWidth());
        frame->setSizePolicy(sizePolicy1);
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Sunken);
        verticalLayout_3 = new QVBoxLayout(frame);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        IconLabel = new QLabel(frame);
        IconLabel->setObjectName(QString::fromUtf8("IconLabel"));
        sizePolicy.setHeightForWidth(IconLabel->sizePolicy().hasHeightForWidth());
        IconLabel->setSizePolicy(sizePolicy);
        IconLabel->setMinimumSize(QSize(500, 161));
        IconLabel->setMaximumSize(QSize(500, 161));
        IconLabel->setText(QString::fromUtf8(""));
        IconLabel->setPixmap(QPixmap(QString::fromUtf8(":/images/new/icon_Logo_App.svg")));

        horizontalLayout_3->addWidget(IconLabel);


        verticalLayout_3->addLayout(horizontalLayout_3);

        verticalLayout_7 = new QVBoxLayout();
        verticalLayout_7->setObjectName(QString::fromUtf8("verticalLayout_7"));
        label_7 = new QLabel(frame);
        label_7->setObjectName(QString::fromUtf8("label_7"));
        label_7->setFocusPolicy(Qt::StrongFocus);
        label_7->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        label_7->setWordWrap(true);

        verticalLayout_7->addWidget(label_7);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QString::fromUtf8("horizontalLayout_5"));
        info_icon = new QLabel(frame);
        info_icon->setObjectName(QString::fromUtf8("info_icon"));
        info_icon->setText(QString::fromUtf8(""));

        horizontalLayout_5->addWidget(info_icon);

        label_6 = new QLabel(frame);
        label_6->setObjectName(QString::fromUtf8("label_6"));
        label_6->setFocusPolicy(Qt::StrongFocus);
        label_6->setOpenExternalLinks(true);

        horizontalLayout_5->addWidget(label_6);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_3);


        verticalLayout_7->addLayout(horizontalLayout_5);


        verticalLayout_3->addLayout(verticalLayout_7);

        line_2 = new QFrame(frame);
        line_2->setObjectName(QString::fromUtf8("line_2"));
        line_2->setFrameShape(QFrame::HLine);
        line_2->setFrameShadow(QFrame::Sunken);

        verticalLayout_3->addWidget(line_2);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName(QString::fromUtf8("horizontalLayout_7"));
        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName(QString::fromUtf8("formLayout_2"));
        formLayout_2->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        label_3 = new QLabel(frame);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setFocusPolicy(Qt::StrongFocus);

        formLayout_2->setWidget(0, QFormLayout::LabelRole, label_3);

        VersionLabel = new QLabel(frame);
        VersionLabel->setObjectName(QString::fromUtf8("VersionLabel"));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        VersionLabel->setFont(font);
        VersionLabel->setFocusPolicy(Qt::StrongFocus);
        VersionLabel->setText(QString::fromUtf8("......"));

        formLayout_2->setWidget(0, QFormLayout::FieldRole, VersionLabel);


        horizontalLayout_7->addLayout(formLayout_2);

        horizontalSpacer_2 = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_2);

        formLayout_3 = new QFormLayout();
        formLayout_3->setObjectName(QString::fromUtf8("formLayout_3"));
        label_4 = new QLabel(frame);
        label_4->setObjectName(QString::fromUtf8("label_4"));
        label_4->setFocusPolicy(Qt::StrongFocus);

        formLayout_3->setWidget(0, QFormLayout::LabelRole, label_4);

        firmwareLabel = new QLabel(frame);
        firmwareLabel->setObjectName(QString::fromUtf8("firmwareLabel"));
        firmwareLabel->setFont(font);
        firmwareLabel->setFocusPolicy(Qt::StrongFocus);
        firmwareLabel->setText(QString::fromUtf8("......"));

        formLayout_3->setWidget(0, QFormLayout::FieldRole, firmwareLabel);


        horizontalLayout_7->addLayout(formLayout_3);

        horizontalSpacer_8 = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_8);

        formLayout_4 = new QFormLayout();
        formLayout_4->setObjectName(QString::fromUtf8("formLayout_4"));
        label_5 = new QLabel(frame);
        label_5->setObjectName(QString::fromUtf8("label_5"));
        label_5->setFocusPolicy(Qt::StrongFocus);

        formLayout_4->setWidget(0, QFormLayout::LabelRole, label_5);

        serialEdit = new QLabel(frame);
        serialEdit->setObjectName(QString::fromUtf8("serialEdit"));
        serialEdit->setFont(font);
        serialEdit->setFocusPolicy(Qt::StrongFocus);
        serialEdit->setText(QString::fromUtf8("......"));

        formLayout_4->setWidget(0, QFormLayout::FieldRole, serialEdit);


        horizontalLayout_7->addLayout(formLayout_4);


        verticalLayout_3->addLayout(horizontalLayout_7);

        line_3 = new QFrame(frame);
        line_3->setObjectName(QString::fromUtf8("line_3"));
        line_3->setFrameShape(QFrame::HLine);
        line_3->setFrameShadow(QFrame::Sunken);

        verticalLayout_3->addWidget(line_3);

        frame_2 = new QFrame(frame);
        frame_2->setObjectName(QString::fromUtf8("frame_2"));
        sizePolicy1.setHeightForWidth(frame_2->sizePolicy().hasHeightForWidth());
        frame_2->setSizePolicy(sizePolicy1);
        frame_2->setFrameShape(QFrame::Box);
        frame_2->setFrameShadow(QFrame::Raised);
        verticalLayout = new QVBoxLayout(frame_2);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        label = new QLabel(frame_2);
        label->setObjectName(QString::fromUtf8("label"));
        QFont font1;
        font1.setPointSize(11);
        font1.setBold(true);
        font1.setWeight(75);
        label->setFont(font1);
        label->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(label);

        line = new QFrame(frame_2);
        line->setObjectName(QString::fromUtf8("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        verticalLayout->addWidget(line);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName(QString::fromUtf8("horizontalLayout_6"));
        storage_info = new QFormLayout();
        storage_info->setObjectName(QString::fromUtf8("storage_info"));
        storage_info->setSizeConstraint(QLayout::SetMinimumSize);
        storage_info->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        label_8 = new QLabel(frame_2);
        label_8->setObjectName(QString::fromUtf8("label_8"));
        label_8->setFont(font);
        label_8->setFocusPolicy(Qt::StrongFocus);

        storage_info->setWidget(0, QFormLayout::LabelRole, label_8);

        sd_id_label = new QLabel(frame_2);
        sd_id_label->setObjectName(QString::fromUtf8("sd_id_label"));
        sd_id_label->setFocusPolicy(Qt::StrongFocus);

        storage_info->setWidget(0, QFormLayout::FieldRole, sd_id_label);

        label_9 = new QLabel(frame_2);
        label_9->setObjectName(QString::fromUtf8("label_9"));
        label_9->setFont(font);
        label_9->setFocusPolicy(Qt::StrongFocus);

        storage_info->setWidget(1, QFormLayout::LabelRole, label_9);

        unencrypted_volume_label = new QLabel(frame_2);
        unencrypted_volume_label->setObjectName(QString::fromUtf8("unencrypted_volume_label"));
        unencrypted_volume_label->setFocusPolicy(Qt::StrongFocus);

        storage_info->setWidget(1, QFormLayout::FieldRole, unencrypted_volume_label);

        label_10 = new QLabel(frame_2);
        label_10->setObjectName(QString::fromUtf8("label_10"));
        label_10->setFont(font);
        label_10->setFocusPolicy(Qt::StrongFocus);

        storage_info->setWidget(2, QFormLayout::LabelRole, label_10);

        encrypted_volume_label = new QLabel(frame_2);
        encrypted_volume_label->setObjectName(QString::fromUtf8("encrypted_volume_label"));
        encrypted_volume_label->setFocusPolicy(Qt::StrongFocus);

        storage_info->setWidget(2, QFormLayout::FieldRole, encrypted_volume_label);

        label_11 = new QLabel(frame_2);
        label_11->setObjectName(QString::fromUtf8("label_11"));
        label_11->setFont(font);
        label_11->setFocusPolicy(Qt::StrongFocus);

        storage_info->setWidget(3, QFormLayout::LabelRole, label_11);

        hidden_volume_label = new QLabel(frame_2);
        hidden_volume_label->setObjectName(QString::fromUtf8("hidden_volume_label"));
        hidden_volume_label->setFocusPolicy(Qt::StrongFocus);

        storage_info->setWidget(3, QFormLayout::FieldRole, hidden_volume_label);

        static_storage_info = new QLabel(frame_2);
        static_storage_info->setObjectName(QString::fromUtf8("static_storage_info"));
        static_storage_info->setFont(font);
        static_storage_info->setFocusPolicy(Qt::StrongFocus);

        storage_info->setWidget(5, QFormLayout::LabelRole, static_storage_info);

        verticalSpacer_3 = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        storage_info->setItem(6, QFormLayout::LabelRole, verticalSpacer_3);

        l_storage_capacity = new QLabel(frame_2);
        l_storage_capacity->setObjectName(QString::fromUtf8("l_storage_capacity"));
        l_storage_capacity->setFocusPolicy(Qt::StrongFocus);
        l_storage_capacity->setText(QString::fromUtf8(""));

        storage_info->setWidget(5, QFormLayout::FieldRole, l_storage_capacity);


        horizontalLayout_6->addLayout(storage_info);

        horizontalSpacer_6 = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_6);

        formLayout = new QFormLayout();
        formLayout->setObjectName(QString::fromUtf8("formLayout"));
        label1 = new QLabel(frame_2);
        label1->setObjectName(QString::fromUtf8("label1"));
        label1->setFocusPolicy(Qt::StrongFocus);

        formLayout->setWidget(1, QFormLayout::LabelRole, label1);

        label2 = new QLabel(frame_2);
        label2->setObjectName(QString::fromUtf8("label2"));
        label2->setFocusPolicy(Qt::StrongFocus);

        formLayout->setWidget(2, QFormLayout::LabelRole, label2);

        admin_retry_label = new QLabel(frame_2);
        admin_retry_label->setObjectName(QString::fromUtf8("admin_retry_label"));
        admin_retry_label->setFocusPolicy(Qt::StrongFocus);

        formLayout->setWidget(1, QFormLayout::FieldRole, admin_retry_label);

        user_retry_label = new QLabel(frame_2);
        user_retry_label->setObjectName(QString::fromUtf8("user_retry_label"));
        user_retry_label->setFocusPolicy(Qt::StrongFocus);

        formLayout->setWidget(2, QFormLayout::FieldRole, user_retry_label);

        label_2 = new QLabel(frame_2);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setFont(font);
        label_2->setFocusPolicy(Qt::StrongFocus);

        formLayout->setWidget(0, QFormLayout::LabelRole, label_2);


        horizontalLayout_6->addLayout(formLayout);


        verticalLayout->addLayout(horizontalLayout_6);

        newsd_label = new QLabel(frame_2);
        newsd_label->setObjectName(QString::fromUtf8("newsd_label"));
        newsd_label->setFont(font);
        newsd_label->setFocusPolicy(Qt::StrongFocus);

        verticalLayout->addWidget(newsd_label);

        not_erased_sd_label = new QLabel(frame_2);
        not_erased_sd_label->setObjectName(QString::fromUtf8("not_erased_sd_label"));
        QFont font2;
        font2.setItalic(true);
        not_erased_sd_label->setFont(font2);
        not_erased_sd_label->setFocusPolicy(Qt::StrongFocus);

        verticalLayout->addWidget(not_erased_sd_label);

        DeviceStatusLabel = new QLabel(frame_2);
        DeviceStatusLabel->setObjectName(QString::fromUtf8("DeviceStatusLabel"));

        verticalLayout->addWidget(DeviceStatusLabel);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        horizontalLayout_4->setSizeConstraint(QLayout::SetMinimumSize);
        warning_sign = new QLabel(frame_2);
        warning_sign->setObjectName(QString::fromUtf8("warning_sign"));
        warning_sign->setScaledContents(true);

        horizontalLayout_4->addWidget(warning_sign);

        label_12 = new QLabel(frame_2);
        label_12->setObjectName(QString::fromUtf8("label_12"));
        label_12->setFont(font);
        label_12->setFocusPolicy(Qt::StrongFocus);

        horizontalLayout_4->addWidget(label_12);

        horizontalSpacer_4 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_4);

        label_13 = new QLabel(frame_2);
        label_13->setObjectName(QString::fromUtf8("label_13"));
        label_13->setFont(font2);
        label_13->setFocusPolicy(Qt::StrongFocus);
        label_13->setWordWrap(true);

        horizontalLayout_4->addWidget(label_13);

        horizontalSpacer_5 = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_5);


        verticalLayout->addLayout(horizontalLayout_4);


        verticalLayout_3->addWidget(frame_2);

        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Minimum);

        verticalLayout_3->addItem(verticalSpacer);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_4);

        AboutLabel_2 = new QLabel(frame);
        AboutLabel_2->setObjectName(QString::fromUtf8("AboutLabel_2"));
        AboutLabel_2->setFocusPolicy(Qt::StrongFocus);
        AboutLabel_2->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        AboutLabel_2->setWordWrap(true);
        AboutLabel_2->setOpenExternalLinks(true);
        AboutLabel_2->setTextInteractionFlags(Qt::LinksAccessibleByKeyboard|Qt::LinksAccessibleByMouse);

        verticalLayout_3->addWidget(AboutLabel_2);


        verticalLayout_2->addWidget(frame);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        btn_3rdparty = new QPushButton(AboutDialog);
        btn_3rdparty->setObjectName(QString::fromUtf8("btn_3rdparty"));

        horizontalLayout->addWidget(btn_3rdparty);

        ButtonStickStatus = new QPushButton(AboutDialog);
        ButtonStickStatus->setObjectName(QString::fromUtf8("ButtonStickStatus"));
        ButtonStickStatus->setEnabled(true);

        horizontalLayout->addWidget(ButtonStickStatus);

        ButtonOK = new QPushButton(AboutDialog);
        ButtonOK->setObjectName(QString::fromUtf8("ButtonOK"));
        ButtonOK->setFocusPolicy(Qt::TabFocus);

        horizontalLayout->addWidget(ButtonOK);


        verticalLayout_2->addLayout(horizontalLayout);

        QWidget::setTabOrder(label_7, label_6);
        QWidget::setTabOrder(label_6, label_3);
        QWidget::setTabOrder(label_3, VersionLabel);
        QWidget::setTabOrder(VersionLabel, label_4);
        QWidget::setTabOrder(label_4, firmwareLabel);
        QWidget::setTabOrder(firmwareLabel, label_5);
        QWidget::setTabOrder(label_5, serialEdit);
        QWidget::setTabOrder(serialEdit, label_2);
        QWidget::setTabOrder(label_2, label1);
        QWidget::setTabOrder(label1, admin_retry_label);
        QWidget::setTabOrder(admin_retry_label, label2);
        QWidget::setTabOrder(label2, user_retry_label);
        QWidget::setTabOrder(user_retry_label, label_8);
        QWidget::setTabOrder(label_8, sd_id_label);
        QWidget::setTabOrder(sd_id_label, label_9);
        QWidget::setTabOrder(label_9, unencrypted_volume_label);
        QWidget::setTabOrder(unencrypted_volume_label, label_10);
        QWidget::setTabOrder(label_10, encrypted_volume_label);
        QWidget::setTabOrder(encrypted_volume_label, label_11);
        QWidget::setTabOrder(label_11, hidden_volume_label);
        QWidget::setTabOrder(hidden_volume_label, static_storage_info);
        QWidget::setTabOrder(static_storage_info, l_storage_capacity);
        QWidget::setTabOrder(l_storage_capacity, newsd_label);
        QWidget::setTabOrder(newsd_label, not_erased_sd_label);
        QWidget::setTabOrder(not_erased_sd_label, label_12);
        QWidget::setTabOrder(label_12, label_13);
        QWidget::setTabOrder(label_13, AboutLabel_2);
        QWidget::setTabOrder(AboutLabel_2, btn_3rdparty);
        QWidget::setTabOrder(btn_3rdparty, ButtonStickStatus);
        QWidget::setTabOrder(ButtonStickStatus, ButtonOK);

        retranslateUi(AboutDialog);

        ButtonOK->setDefault(true);


        QMetaObject::connectSlotsByName(AboutDialog);
    } // setupUi

    void retranslateUi(QDialog *AboutDialog)
    {
        AboutDialog->setWindowTitle(QCoreApplication::translate("AboutDialog", "About", nullptr));
#if QT_CONFIG(accessibility)
        IconLabel->setAccessibleDescription(QCoreApplication::translate("AboutDialog", "Logo", nullptr));
#endif // QT_CONFIG(accessibility)
        label_7->setText(QCoreApplication::translate("AboutDialog", "<html><head/><body><p>This application allows you to configure and use the Nitrokey Pro and Nitrokey Storage.</p></body></html>", nullptr));
        label_6->setText(QCoreApplication::translate("AboutDialog", "<html><head/><body><p><a href=\"https://www.nitrokey.com/start\"><span style=\" text-decoration: underline; color:#c80636;\">Instructions and help</span></a></p></body></html>", nullptr));
        label_3->setText(QCoreApplication::translate("AboutDialog", "App version:", nullptr));
        label_4->setText(QCoreApplication::translate("AboutDialog", "Firmware version:", nullptr));
        label_5->setText(QCoreApplication::translate("AboutDialog", "Card serial number:", nullptr));
#if QT_CONFIG(accessibility)
        serialEdit->setAccessibleName(QString());
#endif // QT_CONFIG(accessibility)
        label->setText(QCoreApplication::translate("AboutDialog", "Status", nullptr));
        label_8->setText(QCoreApplication::translate("AboutDialog", "SD ID:", nullptr));
        sd_id_label->setText(QString());
        label_9->setText(QCoreApplication::translate("AboutDialog", "Unencrypted volume:", nullptr));
        unencrypted_volume_label->setText(QString());
        label_10->setText(QCoreApplication::translate("AboutDialog", "Encrypted volume:", nullptr));
        encrypted_volume_label->setText(QString());
        label_11->setText(QCoreApplication::translate("AboutDialog", "Hidden Volume:", nullptr));
        hidden_volume_label->setText(QString());
        static_storage_info->setText(QCoreApplication::translate("AboutDialog", "Storage Capacity:", nullptr));
        label1->setText(QCoreApplication::translate("AboutDialog", "Admin:", nullptr));
        label2->setText(QCoreApplication::translate("AboutDialog", "User:", nullptr));
        admin_retry_label->setText(QString());
        user_retry_label->setText(QString());
        label_2->setText(QCoreApplication::translate("AboutDialog", "Password retry counters:", nullptr));
        newsd_label->setText(QCoreApplication::translate("AboutDialog", "New SD card found", nullptr));
        not_erased_sd_label->setText(QCoreApplication::translate("AboutDialog", "(Not erased with random data)", nullptr));
        DeviceStatusLabel->setText(QString());
        warning_sign->setText(QString());
        label_12->setText(QCoreApplication::translate("AboutDialog", "<span style=\"color:#c80636\">Warning</span>", nullptr));
        label_13->setText(QCoreApplication::translate("AboutDialog", "Stick is not secure!\n"
"Select Init keys.", nullptr));
        AboutLabel_2->setText(QCoreApplication::translate("AboutDialog", "<html><head/><body><p><span style=\" font-size:10pt; font-style:italic;\">Copyright %1 by NitrokeyUG. </span></p><p><span style=\" font-size:10pt; font-style:italic;\">This software is licensed under the </span><a href=\"https://www.gnu.org/licenses/\"><span style=\" font-size:10pt; font-style:italic; text-decoration: underline; color:#c80636;\">GNU General Public License v3</span></a><span style=\" font-size:10pt; font-style:italic;\">.</span></p><p><a href=\"https://nitrokey.com\"><span style=\" text-decoration: underline; color:#c80636;\">www.nitrokey.com</span></a></p></body></html>", nullptr));
        btn_3rdparty->setText(QCoreApplication::translate("AboutDialog", "Licenses and 3rd-party components", nullptr));
        ButtonStickStatus->setText(QCoreApplication::translate("AboutDialog", "Detailed Status", nullptr));
        ButtonOK->setText(QCoreApplication::translate("AboutDialog", "OK", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AboutDialog: public Ui_AboutDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ABOUTDIALOG_H
