/********************************************************************************
** Form generated from reading UI file 'stick20hiddenvolumedialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STICK20HIDDENVOLUMEDIALOG_H
#define UI_STICK20HIDDENVOLUMEDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_stick20HiddenVolumeDialog
{
public:
    QVBoxLayout *verticalLayout_4;
    QFrame *main_frame;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *top_layout;
    QLabel *l_warning;
    QLabel *l_top_instructions;
    QLabel *l_instructions;
    QGroupBox *password_group;
    QFormLayout *passwordObjects;
    QLabel *label;
    QLineEdit *HVPasswordEdit;
    QLabel *label_4;
    QLineEdit *HVPasswordEdit_2;
    QCheckBox *ShowPasswordCheckBox;
    QVBoxLayout *entropy_verticalLayout;
    QLabel *label_6;
    QProgressBar *password_strength_progressBar;
    QHBoxLayout *chars_kind_layout;
    QCheckBox *cb_length;
    QCheckBox *cb_lower_case;
    QCheckBox *cb_upper_case;
    QCheckBox *cb_numbers;
    QCheckBox *cb_symbols;
    QGroupBox *HV_settings_groupBox;
    QGridLayout *gridLayout;
    QFrame *verticalFrame;
    QVBoxLayout *verticalLayout_6;
    QComboBox *comboBox;
    QLabel *HVSdCardHighWaterMark;
    QFrame *rd_frame;
    QHBoxLayout *horizontalLayout_5;
    QLabel *l_sd_size;
    QSpacerItem *horizontalSpacer_5;
    QLabel *label_5;
    QRadioButton *rd_percent;
    QRadioButton *rd_MB;
    QRadioButton *rd_GB;
    QHBoxLayout *StartControls;
    QLabel *l_sd_start;
    QSpacerItem *horizontalSpacer_2;
    QDoubleSpinBox *StartBlockSpin;
    QHBoxLayout *StopControls;
    QLabel *l_sd_end;
    QSpacerItem *horizontalSpacer_3;
    QDoubleSpinBox *EndBlockSpin;
    QLabel *l_rounding_info;
    QFrame *line;
    QHBoxLayout *bottom_buttons;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *stick20HiddenVolumeDialog)
    {
        if (stick20HiddenVolumeDialog->objectName().isEmpty())
            stick20HiddenVolumeDialog->setObjectName(QString::fromUtf8("stick20HiddenVolumeDialog"));
        stick20HiddenVolumeDialog->resize(525, 668);
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(stick20HiddenVolumeDialog->sizePolicy().hasHeightForWidth());
        stick20HiddenVolumeDialog->setSizePolicy(sizePolicy);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/new/icon_NK.svg"), QSize(), QIcon::Normal, QIcon::Off);
        stick20HiddenVolumeDialog->setWindowIcon(icon);
        verticalLayout_4 = new QVBoxLayout(stick20HiddenVolumeDialog);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        main_frame = new QFrame(stick20HiddenVolumeDialog);
        main_frame->setObjectName(QString::fromUtf8("main_frame"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(main_frame->sizePolicy().hasHeightForWidth());
        main_frame->setSizePolicy(sizePolicy1);
        main_frame->setAutoFillBackground(false);
        main_frame->setFrameShape(QFrame::NoFrame);
        main_frame->setFrameShadow(QFrame::Plain);
        verticalLayout_2 = new QVBoxLayout(main_frame);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        top_layout = new QHBoxLayout();
        top_layout->setObjectName(QString::fromUtf8("top_layout"));
        l_warning = new QLabel(main_frame);
        l_warning->setObjectName(QString::fromUtf8("l_warning"));
        sizePolicy.setHeightForWidth(l_warning->sizePolicy().hasHeightForWidth());
        l_warning->setSizePolicy(sizePolicy);
        l_warning->setMinimumSize(QSize(66, 58));
        l_warning->setMaximumSize(QSize(66, 58));
        l_warning->setBaseSize(QSize(66, 58));
        l_warning->setText(QString::fromUtf8(""));
        l_warning->setPixmap(QPixmap(QString::fromUtf8(":/images/warning.png")));

        top_layout->addWidget(l_warning);

        l_top_instructions = new QLabel(main_frame);
        l_top_instructions->setObjectName(QString::fromUtf8("l_top_instructions"));
        QSizePolicy sizePolicy2(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(l_top_instructions->sizePolicy().hasHeightForWidth());
        l_top_instructions->setSizePolicy(sizePolicy2);
        l_top_instructions->setFocusPolicy(Qt::StrongFocus);
        l_top_instructions->setScaledContents(false);
        l_top_instructions->setWordWrap(true);
        l_top_instructions->setOpenExternalLinks(true);

        top_layout->addWidget(l_top_instructions);


        verticalLayout_2->addLayout(top_layout);

        l_instructions = new QLabel(main_frame);
        l_instructions->setObjectName(QString::fromUtf8("l_instructions"));
        sizePolicy2.setHeightForWidth(l_instructions->sizePolicy().hasHeightForWidth());
        l_instructions->setSizePolicy(sizePolicy2);
        l_instructions->setFocusPolicy(Qt::StrongFocus);
        l_instructions->setWordWrap(true);

        verticalLayout_2->addWidget(l_instructions);

        password_group = new QGroupBox(main_frame);
        password_group->setObjectName(QString::fromUtf8("password_group"));
        passwordObjects = new QFormLayout(password_group);
        passwordObjects->setObjectName(QString::fromUtf8("passwordObjects"));
        label = new QLabel(password_group);
        label->setObjectName(QString::fromUtf8("label"));

        passwordObjects->setWidget(0, QFormLayout::LabelRole, label);

        HVPasswordEdit = new QLineEdit(password_group);
        HVPasswordEdit->setObjectName(QString::fromUtf8("HVPasswordEdit"));
        HVPasswordEdit->setText(QString::fromUtf8("12345678901234567890"));
        HVPasswordEdit->setMaxLength(20);
        HVPasswordEdit->setEchoMode(QLineEdit::Password);

        passwordObjects->setWidget(0, QFormLayout::FieldRole, HVPasswordEdit);

        label_4 = new QLabel(password_group);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        passwordObjects->setWidget(1, QFormLayout::LabelRole, label_4);

        HVPasswordEdit_2 = new QLineEdit(password_group);
        HVPasswordEdit_2->setObjectName(QString::fromUtf8("HVPasswordEdit_2"));
        HVPasswordEdit_2->setFocusPolicy(Qt::StrongFocus);
        HVPasswordEdit_2->setText(QString::fromUtf8("12345678901234567890"));
        HVPasswordEdit_2->setMaxLength(20);
        HVPasswordEdit_2->setEchoMode(QLineEdit::Password);

        passwordObjects->setWidget(1, QFormLayout::FieldRole, HVPasswordEdit_2);

        ShowPasswordCheckBox = new QCheckBox(password_group);
        ShowPasswordCheckBox->setObjectName(QString::fromUtf8("ShowPasswordCheckBox"));

        passwordObjects->setWidget(2, QFormLayout::FieldRole, ShowPasswordCheckBox);

        entropy_verticalLayout = new QVBoxLayout();
        entropy_verticalLayout->setObjectName(QString::fromUtf8("entropy_verticalLayout"));
        label_6 = new QLabel(password_group);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        entropy_verticalLayout->addWidget(label_6);

        password_strength_progressBar = new QProgressBar(password_group);
        password_strength_progressBar->setObjectName(QString::fromUtf8("password_strength_progressBar"));
        password_strength_progressBar->setValue(42);

        entropy_verticalLayout->addWidget(password_strength_progressBar);

        chars_kind_layout = new QHBoxLayout();
        chars_kind_layout->setObjectName(QString::fromUtf8("chars_kind_layout"));
        cb_length = new QCheckBox(password_group);
        cb_length->setObjectName(QString::fromUtf8("cb_length"));
        cb_length->setEnabled(false);
        cb_length->setFocusPolicy(Qt::NoFocus);

        chars_kind_layout->addWidget(cb_length);

        cb_lower_case = new QCheckBox(password_group);
        cb_lower_case->setObjectName(QString::fromUtf8("cb_lower_case"));
        cb_lower_case->setEnabled(false);
        cb_lower_case->setFocusPolicy(Qt::NoFocus);

        chars_kind_layout->addWidget(cb_lower_case);

        cb_upper_case = new QCheckBox(password_group);
        cb_upper_case->setObjectName(QString::fromUtf8("cb_upper_case"));
        cb_upper_case->setEnabled(false);
        cb_upper_case->setFocusPolicy(Qt::NoFocus);
        cb_upper_case->setCheckable(true);

        chars_kind_layout->addWidget(cb_upper_case);

        cb_numbers = new QCheckBox(password_group);
        cb_numbers->setObjectName(QString::fromUtf8("cb_numbers"));
        cb_numbers->setEnabled(false);
        cb_numbers->setFocusPolicy(Qt::NoFocus);

        chars_kind_layout->addWidget(cb_numbers);

        cb_symbols = new QCheckBox(password_group);
        cb_symbols->setObjectName(QString::fromUtf8("cb_symbols"));
        cb_symbols->setEnabled(false);
        cb_symbols->setFocusPolicy(Qt::NoFocus);

        chars_kind_layout->addWidget(cb_symbols);


        entropy_verticalLayout->addLayout(chars_kind_layout);


        passwordObjects->setLayout(3, QFormLayout::SpanningRole, entropy_verticalLayout);


        verticalLayout_2->addWidget(password_group);

        HV_settings_groupBox = new QGroupBox(main_frame);
        HV_settings_groupBox->setObjectName(QString::fromUtf8("HV_settings_groupBox"));
        QSizePolicy sizePolicy3(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(HV_settings_groupBox->sizePolicy().hasHeightForWidth());
        HV_settings_groupBox->setSizePolicy(sizePolicy3);
        HV_settings_groupBox->setMinimumSize(QSize(100, 101));
        HV_settings_groupBox->setCheckable(false);
        gridLayout = new QGridLayout(HV_settings_groupBox);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        verticalFrame = new QFrame(HV_settings_groupBox);
        verticalFrame->setObjectName(QString::fromUtf8("verticalFrame"));
        sizePolicy3.setHeightForWidth(verticalFrame->sizePolicy().hasHeightForWidth());
        verticalFrame->setSizePolicy(sizePolicy3);
        verticalLayout_6 = new QVBoxLayout(verticalFrame);
        verticalLayout_6->setObjectName(QString::fromUtf8("verticalLayout_6"));
        comboBox = new QComboBox(verticalFrame);
        comboBox->addItem(QString());
        comboBox->addItem(QString());
        comboBox->addItem(QString());
        comboBox->addItem(QString());
        comboBox->setObjectName(QString::fromUtf8("comboBox"));

        verticalLayout_6->addWidget(comboBox);

        HVSdCardHighWaterMark = new QLabel(verticalFrame);
        HVSdCardHighWaterMark->setObjectName(QString::fromUtf8("HVSdCardHighWaterMark"));
        HVSdCardHighWaterMark->setText(QString::fromUtf8("SD card information"));
        HVSdCardHighWaterMark->setAlignment(Qt::AlignCenter);

        verticalLayout_6->addWidget(HVSdCardHighWaterMark);

        rd_frame = new QFrame(verticalFrame);
        rd_frame->setObjectName(QString::fromUtf8("rd_frame"));
        rd_frame->setFrameShape(QFrame::Box);
        horizontalLayout_5 = new QHBoxLayout(rd_frame);
        horizontalLayout_5->setObjectName(QString::fromUtf8("horizontalLayout_5"));
        l_sd_size = new QLabel(rd_frame);
        l_sd_size->setObjectName(QString::fromUtf8("l_sd_size"));
        l_sd_size->setFocusPolicy(Qt::StrongFocus);
        l_sd_size->setText(QString::fromUtf8("Storage capacity: %1GB"));

        horizontalLayout_5->addWidget(l_sd_size);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_5);

        label_5 = new QLabel(rd_frame);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        horizontalLayout_5->addWidget(label_5);

        rd_percent = new QRadioButton(rd_frame);
        rd_percent->setObjectName(QString::fromUtf8("rd_percent"));

        horizontalLayout_5->addWidget(rd_percent);

        rd_MB = new QRadioButton(rd_frame);
        rd_MB->setObjectName(QString::fromUtf8("rd_MB"));

        horizontalLayout_5->addWidget(rd_MB);

        rd_GB = new QRadioButton(rd_frame);
        rd_GB->setObjectName(QString::fromUtf8("rd_GB"));

        horizontalLayout_5->addWidget(rd_GB);


        verticalLayout_6->addWidget(rd_frame);

        StartControls = new QHBoxLayout();
        StartControls->setObjectName(QString::fromUtf8("StartControls"));
        l_sd_start = new QLabel(verticalFrame);
        l_sd_start->setObjectName(QString::fromUtf8("l_sd_start"));
        l_sd_start->setText(QString::fromUtf8("Start at %1 of SD size:"));

        StartControls->addWidget(l_sd_start);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        StartControls->addItem(horizontalSpacer_2);

        StartBlockSpin = new QDoubleSpinBox(verticalFrame);
        StartBlockSpin->setObjectName(QString::fromUtf8("StartBlockSpin"));
        sizePolicy2.setHeightForWidth(StartBlockSpin->sizePolicy().hasHeightForWidth());
        StartBlockSpin->setSizePolicy(sizePolicy2);
        StartBlockSpin->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        StartBlockSpin->setMaximum(999999999999999983222784.000000000000000);

        StartControls->addWidget(StartBlockSpin);


        verticalLayout_6->addLayout(StartControls);

        StopControls = new QHBoxLayout();
        StopControls->setObjectName(QString::fromUtf8("StopControls"));
        l_sd_end = new QLabel(verticalFrame);
        l_sd_end->setObjectName(QString::fromUtf8("l_sd_end"));
        l_sd_end->setText(QString::fromUtf8("End at %1 of SD size:"));

        StopControls->addWidget(l_sd_end);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        StopControls->addItem(horizontalSpacer_3);

        EndBlockSpin = new QDoubleSpinBox(verticalFrame);
        EndBlockSpin->setObjectName(QString::fromUtf8("EndBlockSpin"));
        sizePolicy2.setHeightForWidth(EndBlockSpin->sizePolicy().hasHeightForWidth());
        EndBlockSpin->setSizePolicy(sizePolicy2);
        EndBlockSpin->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        EndBlockSpin->setMaximum(99999999999999997748809823456034029568.000000000000000);

        StopControls->addWidget(EndBlockSpin);


        verticalLayout_6->addLayout(StopControls);

        l_rounding_info = new QLabel(verticalFrame);
        l_rounding_info->setObjectName(QString::fromUtf8("l_rounding_info"));
        QSizePolicy sizePolicy4(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(l_rounding_info->sizePolicy().hasHeightForWidth());
        l_rounding_info->setSizePolicy(sizePolicy4);
        l_rounding_info->setMinimumSize(QSize(0, 0));

        verticalLayout_6->addWidget(l_rounding_info);


        gridLayout->addWidget(verticalFrame, 0, 0, 1, 1);


        verticalLayout_2->addWidget(HV_settings_groupBox);


        verticalLayout_4->addWidget(main_frame);

        line = new QFrame(stick20HiddenVolumeDialog);
        line->setObjectName(QString::fromUtf8("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        verticalLayout_4->addWidget(line);

        bottom_buttons = new QHBoxLayout();
        bottom_buttons->setObjectName(QString::fromUtf8("bottom_buttons"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        bottom_buttons->addItem(horizontalSpacer);

        buttonBox = new QDialogButtonBox(stick20HiddenVolumeDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        bottom_buttons->addWidget(buttonBox);


        verticalLayout_4->addLayout(bottom_buttons);

        QWidget::setTabOrder(l_top_instructions, l_instructions);
        QWidget::setTabOrder(l_instructions, HVPasswordEdit);
        QWidget::setTabOrder(HVPasswordEdit, HVPasswordEdit_2);
        QWidget::setTabOrder(HVPasswordEdit_2, ShowPasswordCheckBox);
        QWidget::setTabOrder(ShowPasswordCheckBox, comboBox);
        QWidget::setTabOrder(comboBox, l_sd_size);
        QWidget::setTabOrder(l_sd_size, rd_percent);
        QWidget::setTabOrder(rd_percent, rd_MB);
        QWidget::setTabOrder(rd_MB, rd_GB);
        QWidget::setTabOrder(rd_GB, StartBlockSpin);
        QWidget::setTabOrder(StartBlockSpin, EndBlockSpin);

        retranslateUi(stick20HiddenVolumeDialog);

        QMetaObject::connectSlotsByName(stick20HiddenVolumeDialog);
    } // setupUi

    void retranslateUi(QDialog *stick20HiddenVolumeDialog)
    {
        stick20HiddenVolumeDialog->setWindowTitle(QCoreApplication::translate("stick20HiddenVolumeDialog", "Setup hidden volume", nullptr));
        l_top_instructions->setText(QCoreApplication::translate("stick20HiddenVolumeDialog", "<html><head/><body><p><span style=\" font-weight:600;\">You should understand the properties of hidden volumes before proceeding. It can destroy your encrypted data! <br/>Please read </span><a href=\"https://www.nitrokey.com/documentation/hidden-volumes\"><span style=\" font-weight:600; text-decoration: underline; color:#0000ff;\">these instructions</span></a><span style=\" font-weight:600;\"> first.</span></p></body></html>", nullptr));
        l_instructions->setText(QCoreApplication::translate("stick20HiddenVolumeDialog", "<html><head/><body><p>1. You may want to copy some innocuous files to the encrypted data.<br/>2. Configure hidden volumes in this dialogue. <br/>3. Once you configured a hidden volume you must not use/write to the encryption volume anymore. Otherwise it may destroy the data in your hidden volume.</p></body></html>", nullptr));
        password_group->setTitle(QCoreApplication::translate("stick20HiddenVolumeDialog", "Password settings", nullptr));
        label->setText(QCoreApplication::translate("stick20HiddenVolumeDialog", "Password:", nullptr));
#if QT_CONFIG(accessibility)
        HVPasswordEdit->setAccessibleName(QCoreApplication::translate("stick20HiddenVolumeDialog", "Hidden volume password", nullptr));
#endif // QT_CONFIG(accessibility)
#if QT_CONFIG(accessibility)
        HVPasswordEdit->setAccessibleDescription(QCoreApplication::translate("stick20HiddenVolumeDialog", "Please use shift+tab key shortcut for instructions", nullptr));
#endif // QT_CONFIG(accessibility)
        label_4->setText(QCoreApplication::translate("stick20HiddenVolumeDialog", "Password:", nullptr));
#if QT_CONFIG(accessibility)
        HVPasswordEdit_2->setAccessibleName(QCoreApplication::translate("stick20HiddenVolumeDialog", "Hidden volume password (repeated)", nullptr));
#endif // QT_CONFIG(accessibility)
        ShowPasswordCheckBox->setText(QCoreApplication::translate("stick20HiddenVolumeDialog", "Show password", nullptr));
        label_6->setText(QCoreApplication::translate("stick20HiddenVolumeDialog", "Password strength:", nullptr));
#if QT_CONFIG(accessibility)
        password_strength_progressBar->setAccessibleName(QCoreApplication::translate("stick20HiddenVolumeDialog", "Password strength:", nullptr));
#endif // QT_CONFIG(accessibility)
        cb_length->setText(QCoreApplication::translate("stick20HiddenVolumeDialog", "length", nullptr));
        cb_lower_case->setText(QCoreApplication::translate("stick20HiddenVolumeDialog", "lower case", nullptr));
        cb_upper_case->setText(QCoreApplication::translate("stick20HiddenVolumeDialog", "upper case", nullptr));
        cb_numbers->setText(QCoreApplication::translate("stick20HiddenVolumeDialog", "numbers", nullptr));
        cb_symbols->setText(QCoreApplication::translate("stick20HiddenVolumeDialog", "symbols", nullptr));
        HV_settings_groupBox->setTitle(QCoreApplication::translate("stick20HiddenVolumeDialog", "Hidden Volume settings", nullptr));
        comboBox->setItemText(0, QCoreApplication::translate("stick20HiddenVolumeDialog", "Hidden volume slot 1", nullptr));
        comboBox->setItemText(1, QCoreApplication::translate("stick20HiddenVolumeDialog", "Hidden volume slot 2", nullptr));
        comboBox->setItemText(2, QCoreApplication::translate("stick20HiddenVolumeDialog", "Hidden volume slot 3", nullptr));
        comboBox->setItemText(3, QCoreApplication::translate("stick20HiddenVolumeDialog", "Hidden volume slot 4", nullptr));

#if QT_CONFIG(accessibility)
        comboBox->setAccessibleDescription(QCoreApplication::translate("stick20HiddenVolumeDialog", "Slot under which hidden volume information will be stored", nullptr));
#endif // QT_CONFIG(accessibility)
        label_5->setText(QCoreApplication::translate("stick20HiddenVolumeDialog", "Unit:", nullptr));
#if QT_CONFIG(accessibility)
        rd_percent->setAccessibleName(QString());
#endif // QT_CONFIG(accessibility)
#if QT_CONFIG(accessibility)
        rd_percent->setAccessibleDescription(QCoreApplication::translate("stick20HiddenVolumeDialog", "Use this as hidden volume size unit", nullptr));
#endif // QT_CONFIG(accessibility)
        rd_percent->setText(QCoreApplication::translate("stick20HiddenVolumeDialog", "%", nullptr));
#if QT_CONFIG(accessibility)
        rd_MB->setAccessibleDescription(QCoreApplication::translate("stick20HiddenVolumeDialog", "Use this as hidden volume size unit", nullptr));
#endif // QT_CONFIG(accessibility)
        rd_MB->setText(QCoreApplication::translate("stick20HiddenVolumeDialog", "MB", nullptr));
#if QT_CONFIG(accessibility)
        rd_GB->setAccessibleDescription(QCoreApplication::translate("stick20HiddenVolumeDialog", "Use this as hidden volume size unit", nullptr));
#endif // QT_CONFIG(accessibility)
        rd_GB->setText(QCoreApplication::translate("stick20HiddenVolumeDialog", "GB", nullptr));
#if QT_CONFIG(accessibility)
        StartBlockSpin->setAccessibleName(QString());
#endif // QT_CONFIG(accessibility)
        l_rounding_info->setText(QCoreApplication::translate("stick20HiddenVolumeDialog", "Size will be rounded down to integral percent of total storage size (%1MB)", nullptr));
    } // retranslateUi

};

namespace Ui {
    class stick20HiddenVolumeDialog: public Ui_stick20HiddenVolumeDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_STICK20HIDDENVOLUMEDIALOG_H
