/****************************************************************************
** Meta object code from reading C++ file 'StorageActions.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.14)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../src/GUI/StorageActions.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'StorageActions.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.14. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_StorageActions_t {
    QByteArrayData data[25];
    char stringdata0[696];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_StorageActions_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_StorageActions_t qt_meta_stringdata_StorageActions = {
    {
QT_MOC_LITERAL(0, 0, 14), // "StorageActions"
QT_MOC_LITERAL(1, 15, 20), // "storageStatusChanged"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 20), // "storageStatusUpdated"
QT_MOC_LITERAL(4, 58, 20), // "longOperationStarted"
QT_MOC_LITERAL(5, 79, 12), // "FactoryReset"
QT_MOC_LITERAL(6, 92, 23), // "on_StorageStatusChanged"
QT_MOC_LITERAL(7, 116, 32), // "startStick20DestroyCryptedVolume"
QT_MOC_LITERAL(8, 149, 21), // "fillSDWithRandomChars"
QT_MOC_LITERAL(9, 171, 37), // "startStick20FillSDCardWithRan..."
QT_MOC_LITERAL(10, 209, 31), // "startStick20EnableCryptedVolume"
QT_MOC_LITERAL(11, 241, 32), // "startStick20DisableCryptedVolume"
QT_MOC_LITERAL(12, 274, 30), // "startStick20EnableHiddenVolume"
QT_MOC_LITERAL(13, 305, 31), // "startStick20DisableHiddenVolume"
QT_MOC_LITERAL(14, 337, 21), // "startLockDeviceAction"
QT_MOC_LITERAL(15, 359, 20), // "ask_for_confirmation"
QT_MOC_LITERAL(16, 380, 38), // "startStick20SetReadOnlyUncryp..."
QT_MOC_LITERAL(17, 419, 39), // "startStick20SetReadWriteUncry..."
QT_MOC_LITERAL(18, 459, 29), // "startStick20LockStickHardware"
QT_MOC_LITERAL(19, 489, 32), // "startStick20EnableFirmwareUpdate"
QT_MOC_LITERAL(20, 522, 32), // "startStick20ExportFirmwareToFile"
QT_MOC_LITERAL(21, 555, 31), // "startStick20ClearNewSdCardFound"
QT_MOC_LITERAL(22, 587, 29), // "startStick20SetupHiddenVolume"
QT_MOC_LITERAL(23, 617, 38), // "startStick20SetReadOnlyEncryp..."
QT_MOC_LITERAL(24, 656, 39) // "startStick20SetReadWriteEncry..."

    },
    "StorageActions\0storageStatusChanged\0"
    "\0storageStatusUpdated\0longOperationStarted\0"
    "FactoryReset\0on_StorageStatusChanged\0"
    "startStick20DestroyCryptedVolume\0"
    "fillSDWithRandomChars\0"
    "startStick20FillSDCardWithRandomChars\0"
    "startStick20EnableCryptedVolume\0"
    "startStick20DisableCryptedVolume\0"
    "startStick20EnableHiddenVolume\0"
    "startStick20DisableHiddenVolume\0"
    "startLockDeviceAction\0ask_for_confirmation\0"
    "startStick20SetReadOnlyUncryptedVolume\0"
    "startStick20SetReadWriteUncryptedVolume\0"
    "startStick20LockStickHardware\0"
    "startStick20EnableFirmwareUpdate\0"
    "startStick20ExportFirmwareToFile\0"
    "startStick20ClearNewSdCardFound\0"
    "startStick20SetupHiddenVolume\0"
    "startStick20SetReadOnlyEncryptedVolume\0"
    "startStick20SetReadWriteEncryptedVolume"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_StorageActions[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      22,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  124,    2, 0x06 /* Public */,
       3,    0,  125,    2, 0x06 /* Public */,
       4,    0,  126,    2, 0x06 /* Public */,
       5,    0,  127,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,  128,    2, 0x08 /* Private */,
       7,    1,  129,    2, 0x0a /* Public */,
       9,    0,  132,    2, 0x0a /* Public */,
      10,    0,  133,    2, 0x0a /* Public */,
      11,    0,  134,    2, 0x0a /* Public */,
      12,    0,  135,    2, 0x0a /* Public */,
      13,    0,  136,    2, 0x0a /* Public */,
      14,    1,  137,    2, 0x0a /* Public */,
      14,    0,  140,    2, 0x2a /* Public | MethodCloned */,
      16,    0,  141,    2, 0x0a /* Public */,
      17,    0,  142,    2, 0x0a /* Public */,
      18,    0,  143,    2, 0x0a /* Public */,
      19,    0,  144,    2, 0x0a /* Public */,
      20,    0,  145,    2, 0x0a /* Public */,
      21,    0,  146,    2, 0x0a /* Public */,
      22,    0,  147,    2, 0x0a /* Public */,
      23,    0,  148,    2, 0x0a /* Public */,
      24,    0,  149,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   15,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void StorageActions::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<StorageActions *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->storageStatusChanged(); break;
        case 1: _t->storageStatusUpdated(); break;
        case 2: _t->longOperationStarted(); break;
        case 3: _t->FactoryReset(); break;
        case 4: _t->on_StorageStatusChanged(); break;
        case 5: _t->startStick20DestroyCryptedVolume((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->startStick20FillSDCardWithRandomChars(); break;
        case 7: _t->startStick20EnableCryptedVolume(); break;
        case 8: _t->startStick20DisableCryptedVolume(); break;
        case 9: _t->startStick20EnableHiddenVolume(); break;
        case 10: _t->startStick20DisableHiddenVolume(); break;
        case 11: _t->startLockDeviceAction((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->startLockDeviceAction(); break;
        case 13: _t->startStick20SetReadOnlyUncryptedVolume(); break;
        case 14: _t->startStick20SetReadWriteUncryptedVolume(); break;
        case 15: _t->startStick20LockStickHardware(); break;
        case 16: _t->startStick20EnableFirmwareUpdate(); break;
        case 17: _t->startStick20ExportFirmwareToFile(); break;
        case 18: _t->startStick20ClearNewSdCardFound(); break;
        case 19: _t->startStick20SetupHiddenVolume(); break;
        case 20: _t->startStick20SetReadOnlyEncryptedVolume(); break;
        case 21: _t->startStick20SetReadWriteEncryptedVolume(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (StorageActions::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&StorageActions::storageStatusChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (StorageActions::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&StorageActions::storageStatusUpdated)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (StorageActions::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&StorageActions::longOperationStarted)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (StorageActions::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&StorageActions::FactoryReset)) {
                *result = 3;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject StorageActions::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_StorageActions.data,
    qt_meta_data_StorageActions,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *StorageActions::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StorageActions::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_StorageActions.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int StorageActions::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void StorageActions::storageStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void StorageActions::storageStatusUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void StorageActions::longOperationStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void StorageActions::FactoryReset()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
