/********************************************************************************
** Form generated from reading UI file 'stick20responsedialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STICK20RESPONSEDIALOG_H
#define UI_STICK20RESPONSEDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_Stick20ResponseDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QLabel *HeaderText;
    QHBoxLayout *horizontalLayout_2;
    QLabel *LabelProgressWheel;
    QLabel *label;
    QSpacerItem *horizontalSpacer_3;
    QProgressBar *progressBar;
    QLabel *OutputText;
    QSpacerItem *verticalSpacer;

    void setupUi(QDialog *Stick20ResponseDialog)
    {
        if (Stick20ResponseDialog->objectName().isEmpty())
            Stick20ResponseDialog->setObjectName(QString::fromUtf8("Stick20ResponseDialog"));
        Stick20ResponseDialog->setWindowModality(Qt::ApplicationModal);
        Stick20ResponseDialog->resize(342, 123);
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(Stick20ResponseDialog->sizePolicy().hasHeightForWidth());
        Stick20ResponseDialog->setSizePolicy(sizePolicy);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/new/icon_NK.svg"), QSize(), QIcon::Normal, QIcon::Off);
        icon.addFile(QString::fromUtf8(":/images/new/icon_NK.svg"), QSize(), QIcon::Normal, QIcon::On);
        Stick20ResponseDialog->setWindowIcon(icon);
        verticalLayout_2 = new QVBoxLayout(Stick20ResponseDialog);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        verticalLayout_2->setSizeConstraint(QLayout::SetFixedSize);
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        HeaderText = new QLabel(Stick20ResponseDialog);
        HeaderText->setObjectName(QString::fromUtf8("HeaderText"));
        QFont font;
        font.setPointSize(11);
        font.setBold(false);
        font.setWeight(50);
        HeaderText->setFont(font);
        HeaderText->setText(QString::fromUtf8("HeaderLabel"));
        HeaderText->setTextFormat(Qt::PlainText);
        HeaderText->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(HeaderText);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        LabelProgressWheel = new QLabel(Stick20ResponseDialog);
        LabelProgressWheel->setObjectName(QString::fromUtf8("LabelProgressWheel"));
        LabelProgressWheel->setText(QString::fromUtf8("LabelProgressWheel"));
        LabelProgressWheel->setAlignment(Qt::AlignCenter);

        horizontalLayout_2->addWidget(LabelProgressWheel);

        label = new QLabel(Stick20ResponseDialog);
        label->setObjectName(QString::fromUtf8("label"));
        QFont font1;
        font1.setPointSize(13);
        label->setFont(font1);

        horizontalLayout_2->addWidget(label);

        horizontalSpacer_3 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);


        verticalLayout->addLayout(horizontalLayout_2);

        progressBar = new QProgressBar(Stick20ResponseDialog);
        progressBar->setObjectName(QString::fromUtf8("progressBar"));
        progressBar->setValue(24);

        verticalLayout->addWidget(progressBar);


        verticalLayout_2->addLayout(verticalLayout);

        OutputText = new QLabel(Stick20ResponseDialog);
        OutputText->setObjectName(QString::fromUtf8("OutputText"));
        QFont font2;
        font2.setFamily(QString::fromUtf8("Courier 10 Pitch"));
        font2.setPointSize(10);
        font2.setBold(false);
        font2.setItalic(false);
        font2.setWeight(50);
        OutputText->setFont(font2);
        OutputText->setText(QString::fromUtf8("TextLabel"));
        OutputText->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        OutputText->setWordWrap(true);

        verticalLayout_2->addWidget(OutputText);

        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        retranslateUi(Stick20ResponseDialog);
        QObject::connect(HeaderText, SIGNAL(customContextMenuRequested(QPoint)), Stick20ResponseDialog, SLOT(open()));

        QMetaObject::connectSlotsByName(Stick20ResponseDialog);
    } // setupUi

    void retranslateUi(QDialog *Stick20ResponseDialog)
    {
        Stick20ResponseDialog->setWindowTitle(QCoreApplication::translate("Stick20ResponseDialog", "Progress", nullptr));
        label->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class Stick20ResponseDialog: public Ui_Stick20ResponseDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_STICK20RESPONSEDIALOG_H
