/********************************************************************************
** Form generated from reading UI file 'pindialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PINDIALOG_H
#define UI_PINDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_PinDialog
{
public:
    QVBoxLayout *verticalLayout;
    QFrame *frame;
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    QLineEdit *lineEdit;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *checkBox;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *verticalSpacer;
    QFrame *line;
    QHBoxLayout *horizontalLayout;
    QLabel *status;
    QSpacerItem *horizontalSpacer;
    QPushButton *cancelButton;
    QPushButton *okButton;

    void setupUi(QDialog *PinDialog)
    {
        if (PinDialog->objectName().isEmpty())
            PinDialog->setObjectName(QString::fromUtf8("PinDialog"));
        PinDialog->resize(358, 155);
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PinDialog->sizePolicy().hasHeightForWidth());
        PinDialog->setSizePolicy(sizePolicy);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/new/icon_NK.svg"), QSize(), QIcon::Normal, QIcon::Off);
        PinDialog->setWindowIcon(icon);
        verticalLayout = new QVBoxLayout(PinDialog);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        frame = new QFrame(PinDialog);
        frame->setObjectName(QString::fromUtf8("frame"));
        sizePolicy.setHeightForWidth(frame->sizePolicy().hasHeightForWidth());
        frame->setSizePolicy(sizePolicy);
        frame->setAutoFillBackground(false);
        frame->setFrameShape(QFrame::NoFrame);
        frame->setFrameShadow(QFrame::Plain);
        verticalLayout_2 = new QVBoxLayout(frame);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        label = new QLabel(frame);
        label->setObjectName(QString::fromUtf8("label"));
        QSizePolicy sizePolicy1(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy1);

        verticalLayout_2->addWidget(label);

        lineEdit = new QLineEdit(frame);
        lineEdit->setObjectName(QString::fromUtf8("lineEdit"));
        lineEdit->setMaxLength(39);
        lineEdit->setEchoMode(QLineEdit::Password);

        verticalLayout_2->addWidget(lineEdit);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        checkBox = new QCheckBox(frame);
        checkBox->setObjectName(QString::fromUtf8("checkBox"));
        sizePolicy1.setHeightForWidth(checkBox->sizePolicy().hasHeightForWidth());
        checkBox->setSizePolicy(sizePolicy1);

        horizontalLayout_2->addWidget(checkBox);

        horizontalSpacer_3 = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);


        verticalLayout_2->addLayout(horizontalLayout_2);


        verticalLayout->addWidget(frame);

        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        verticalLayout->addItem(verticalSpacer);

        line = new QFrame(PinDialog);
        line->setObjectName(QString::fromUtf8("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        verticalLayout->addWidget(line);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        status = new QLabel(PinDialog);
        status->setObjectName(QString::fromUtf8("status"));
        status->setFocusPolicy(Qt::StrongFocus);
        status->setText(QString::fromUtf8("TextLabel"));

        horizontalLayout->addWidget(status);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        cancelButton = new QPushButton(PinDialog);
        cancelButton->setObjectName(QString::fromUtf8("cancelButton"));
        cancelButton->setFocusPolicy(Qt::TabFocus);
        cancelButton->setAutoDefault(false);

        horizontalLayout->addWidget(cancelButton);

        okButton = new QPushButton(PinDialog);
        okButton->setObjectName(QString::fromUtf8("okButton"));
        okButton->setFocusPolicy(Qt::TabFocus);
        okButton->setAutoDefault(true);

        horizontalLayout->addWidget(okButton);


        verticalLayout->addLayout(horizontalLayout);

        QWidget::setTabOrder(lineEdit, checkBox);

        retranslateUi(PinDialog);
        QObject::connect(cancelButton, SIGNAL(clicked()), PinDialog, SLOT(reject()));

        cancelButton->setDefault(false);
        okButton->setDefault(true);


        QMetaObject::connectSlotsByName(PinDialog);
    } // setupUi

    void retranslateUi(QDialog *PinDialog)
    {
        PinDialog->setWindowTitle(QCoreApplication::translate("PinDialog", "Password dialog", nullptr));
        label->setText(QCoreApplication::translate("PinDialog", "Enter card password:", nullptr));
#if QT_CONFIG(accessibility)
        lineEdit->setAccessibleName(QCoreApplication::translate("PinDialog", "Enter card PIN", nullptr));
#endif // QT_CONFIG(accessibility)
        checkBox->setText(QCoreApplication::translate("PinDialog", "Show password", nullptr));
        cancelButton->setText(QCoreApplication::translate("PinDialog", "&Cancel", nullptr));
        okButton->setText(QCoreApplication::translate("PinDialog", "&OK", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PinDialog: public Ui_PinDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PINDIALOG_H
