/********************************************************************************
** Form generated from reading UI file 'stick20lockfirmwaredialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STICK20LOCKFIRMWAREDIALOG_H
#define UI_STICK20LOCKFIRMWAREDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_stick20LockFirmwareDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QFrame *frame;
    QVBoxLayout *verticalLayout;
    QLabel *label_2;
    QLabel *label;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *stick20LockFirmwareDialog)
    {
        if (stick20LockFirmwareDialog->objectName().isEmpty())
            stick20LockFirmwareDialog->setObjectName(QString::fromUtf8("stick20LockFirmwareDialog"));
        stick20LockFirmwareDialog->resize(315, 229);
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(stick20LockFirmwareDialog->sizePolicy().hasHeightForWidth());
        stick20LockFirmwareDialog->setSizePolicy(sizePolicy);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/new/icon_NK.svg"), QSize(), QIcon::Normal, QIcon::Off);
        stick20LockFirmwareDialog->setWindowIcon(icon);
        verticalLayout_2 = new QVBoxLayout(stick20LockFirmwareDialog);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        frame = new QFrame(stick20LockFirmwareDialog);
        frame->setObjectName(QString::fromUtf8("frame"));
        frame->setAutoFillBackground(false);
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Sunken);
        verticalLayout = new QVBoxLayout(frame);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        label_2 = new QLabel(frame);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        QFont font;
        font.setPointSize(16);
        font.setBold(true);
        font.setWeight(75);
        label_2->setFont(font);
        label_2->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(label_2);

        label = new QLabel(frame);
        label->setObjectName(QString::fromUtf8("label"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy1);
        label->setWordWrap(true);

        verticalLayout->addWidget(label);


        verticalLayout_2->addWidget(frame);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        buttonBox = new QDialogButtonBox(stick20LockFirmwareDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        horizontalLayout->addWidget(buttonBox);


        verticalLayout_2->addLayout(horizontalLayout);


        retranslateUi(stick20LockFirmwareDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), stick20LockFirmwareDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), stick20LockFirmwareDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(stick20LockFirmwareDialog);
    } // setupUi

    void retranslateUi(QDialog *stick20LockFirmwareDialog)
    {
        stick20LockFirmwareDialog->setWindowTitle(QCoreApplication::translate("stick20LockFirmwareDialog", "Lock Firmware", nullptr));
        label_2->setText(QCoreApplication::translate("stick20LockFirmwareDialog", "Lock Firmware", nullptr));
        label->setText(QCoreApplication::translate("stick20LockFirmwareDialog", "<html><head/><body><p>When you select &quot;OK&quot; the stick lock the firmware and close the hardware debug port.This disables any external hardware access to the data in the device (processor).</p><p>There is no way back! </p><p>After this you can't update the firmware.</p></body></html>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class stick20LockFirmwareDialog: public Ui_stick20LockFirmwareDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_STICK20LOCKFIRMWAREDIALOG_H
