/********************************************************************************
** Form generated from reading UI file 'mainwindow.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINWINDOW_H
#define UI_MAINWINDOW_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStatusBar>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_MainWindow
{
public:
    QWidget *centralWidget;
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tab_5;
    QGridLayout *gridLayout_6;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout_5;
    QPushButton *btn_dial_PWS;
    QPushButton *btn_dial_EV;
    QPushButton *btn_dial_HV;
    QPushButton *btn_dial_lock;
    QPushButton *btn_dial_help;
    QPushButton *btn_dial_quit;
    QWidget *tab;
    QVBoxLayout *verticalLayout_16;
    QFrame *frame_8;
    QVBoxLayout *verticalLayout_11;
    QLabel *label_24;
    QHBoxLayout *horizontalLayout_14;
    QRadioButton *radioButton_2;
    QRadioButton *radioButton;
    QLabel *label_25;
    QSpacerItem *horizontalSpacer_14;
    QHBoxLayout *horizontalLayout_9;
    QLabel *label;
    QComboBox *slotComboBox;
    QLabel *label_2;
    QLineEdit *nameEdit;
    QPushButton *eraseButton;
    QFrame *frame;
    QVBoxLayout *verticalLayout_7;
    QLabel *label_21;
    QFormLayout *formLayout_4;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout_6;
    QRadioButton *base32RadioButton;
    QRadioButton *hexRadioButton;
    QSpacerItem *horizontalSpacer_2;
    QLabel *l_supportedLength;
    QLabel *label_3;
    QVBoxLayout *verticalLayout_6;
    QLineEdit *secretEdit;
    QLabel *labelNotify;
    QHBoxLayout *horizontalLayout_4;
    QCheckBox *checkBox;
    QSpacerItem *horizontalSpacer_13;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_7;
    QSpinBox *secret_key_generated_len;
    QPushButton *randomSecretButton;
    QPushButton *btn_copyToClipboard;
    QLabel *label_26;
    QFrame *frame_2;
    QVBoxLayout *verticalLayout_9;
    QLabel *label_22;
    QFormLayout *formLayout_5;
    QVBoxLayout *verticalLayout_5;
    QHBoxLayout *horizontalLayout_7;
    QLineEdit *counterEdit;
    QPushButton *setToZeroButton;
    QPushButton *setToRandomButton;
    QSpacerItem *verticalSpacer_3;
    QHBoxLayout *horizontalLayout_8;
    QRadioButton *digits6radioButton;
    QRadioButton *digits8radioButton;
    QSpacerItem *horizontalSpacer_6;
    QHBoxLayout *horizontalLayout_15;
    QSpinBox *intervalSpinBox;
    QSpacerItem *horizontalSpacer_10;
    QLabel *label_6;
    QLabel *label_5;
    QLabel *intervalLabel;
    QSpacerItem *verticalSpacer;
    QFrame *line;
    QHBoxLayout *horizontalLayout;
    QProgressBar *progressBar;
    QSpacerItem *horizontalSpacer;
    QPushButton *cancelButton;
    QPushButton *writeButton;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout_14;
    QFrame *frame_4;
    QVBoxLayout *verticalLayout_12;
    QLabel *label_11;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *enableUserPasswordCheckBox;
    QCheckBox *deleteUserPasswordCheckBox;
    QSpacerItem *verticalSpacer_2;
    QFrame *line_2;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer_4;
    QPushButton *generalCancelButton;
    QPushButton *writeGeneralConfigButton;
    QWidget *tab_3;
    QVBoxLayout *verticalLayout_19;
    QFrame *frame_7;
    QVBoxLayout *verticalLayout_18;
    QGridLayout *gridLayout;
    QLineEdit *PWS_EditPassword;
    QLineEdit *PWS_EditLoginName;
    QLabel *label_19;
    QLineEdit *PWS_EditSlotName;
    QLabel *label_18;
    QPushButton *PWS_ButtonClearSlot;
    QLabel *label_17;
    QComboBox *PWS_ComboBoxSelectSlot;
    QPushButton *PWS_ButtonCreatePW;
    QLabel *label_16;
    QCheckBox *PWS_CheckBoxHideSecret;
    QLabel *l_chars_left_info;
    QLabel *l_c_name;
    QLabel *l_c_login;
    QLabel *l_c_password;
    QLabel *l_utf8_info;
    QSpacerItem *verticalSpacer_9;
    QFrame *line_3;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *PWS_ButtonEnable;
    QPushButton *PWS_Lock;
    QProgressBar *PWS_progressBar;
    QSpacerItem *horizontalSpacer_3;
    QPushButton *PWS_ButtonClose;
    QPushButton *PWS_ButtonSaveSlot;
    QWidget *tab_4;
    QVBoxLayout *verticalLayout_73;
    QVBoxLayout *verticalLayout_72;
    QFrame *frame_9;
    QVBoxLayout *verticalLayout_15;
    QGroupBox *gr_general;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_19;
    QCheckBox *cb_first_run_message;
    QCheckBox *cb_show_window_on_start;
    QHBoxLayout *horizontalLayout_17;
    QCheckBox *cb_hide_main_window_on_close;
    QCheckBox *cb_hide_main_window_on_connection;
    QCheckBox *cb_show_main_window_on_connection;
    QCheckBox *cb_check_symlink;
    QCheckBox *cb_device_connection_message;
    QHBoxLayout *horizontalLayout_12;
    QLabel *label_28;
    QComboBox *combo_languages;
    QVBoxLayout *verticalLayout_71;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_3;
    QLineEdit *edit_debug_file_path;
    QSpinBox *spin_debug_verbosity;
    QLabel *label_10;
    QLabel *label_20;
    QCheckBox *cb_debug_enabled;
    QPushButton *btn_select_debug_console;
    QPushButton *btn_select_debug_file_path;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_4;
    QSpinBox *spin_OTP_time;
    QLabel *label_30;
    QSpinBox *spin_PWS_time;
    QLabel *label_31;
    QSpacerItem *horizontalSpacer_7;
    QSpacerItem *verticalSpacer_4;
    QFrame *line_10;
    QHBoxLayout *horizontalLayout_11;
    QSpacerItem *horizontalSpacer_5;
    QPushButton *btn_cancelSettings;
    QPushButton *btn_writeSettings;
    QStatusBar *statusBar;
    QMenuBar *menuBar;

    void setupUi(QMainWindow *MainWindow)
    {
        if (MainWindow->objectName().isEmpty())
            MainWindow->setObjectName(QString::fromUtf8("MainWindow"));
        MainWindow->resize(932, 750);
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(MainWindow->sizePolicy().hasHeightForWidth());
        MainWindow->setSizePolicy(sizePolicy);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/new/icon_NK.svg"), QSize(), QIcon::Normal, QIcon::Off);
        MainWindow->setWindowIcon(icon);
        MainWindow->setAutoFillBackground(true);
        centralWidget = new QWidget(MainWindow);
        centralWidget->setObjectName(QString::fromUtf8("centralWidget"));
        verticalLayout = new QVBoxLayout(centralWidget);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        tabWidget = new QTabWidget(centralWidget);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        sizePolicy.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy);
        tabWidget->setTabPosition(QTabWidget::North);
        tabWidget->setTabShape(QTabWidget::Rounded);
        tabWidget->setElideMode(Qt::ElideNone);
        tabWidget->setDocumentMode(false);
        tabWidget->setTabsClosable(false);
        tabWidget->setMovable(false);
        tab_5 = new QWidget();
        tab_5->setObjectName(QString::fromUtf8("tab_5"));
        gridLayout_6 = new QGridLayout(tab_5);
        gridLayout_6->setSpacing(6);
        gridLayout_6->setContentsMargins(11, 11, 11, 11);
        gridLayout_6->setObjectName(QString::fromUtf8("gridLayout_6"));
        groupBox_3 = new QGroupBox(tab_5);
        groupBox_3->setObjectName(QString::fromUtf8("groupBox_3"));
        QSizePolicy sizePolicy1(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(groupBox_3->sizePolicy().hasHeightForWidth());
        groupBox_3->setSizePolicy(sizePolicy1);
        groupBox_3->setMinimumSize(QSize(561, 211));
        groupBox_3->setAlignment(Qt::AlignCenter);
        groupBox_3->setFlat(false);
        groupBox_3->setCheckable(false);
        gridLayout_5 = new QGridLayout(groupBox_3);
        gridLayout_5->setSpacing(6);
        gridLayout_5->setContentsMargins(11, 11, 11, 11);
        gridLayout_5->setObjectName(QString::fromUtf8("gridLayout_5"));
        btn_dial_PWS = new QPushButton(groupBox_3);
        btn_dial_PWS->setObjectName(QString::fromUtf8("btn_dial_PWS"));
        btn_dial_PWS->setEnabled(true);
        sizePolicy.setHeightForWidth(btn_dial_PWS->sizePolicy().hasHeightForWidth());
        btn_dial_PWS->setSizePolicy(sizePolicy);
        btn_dial_PWS->setStyleSheet(QString::fromUtf8(""));
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/images/new/icon_safe.svg"), QSize(), QIcon::Normal, QIcon::Off);
        btn_dial_PWS->setIcon(icon1);

        gridLayout_5->addWidget(btn_dial_PWS, 0, 0, 1, 1);

        btn_dial_EV = new QPushButton(groupBox_3);
        btn_dial_EV->setObjectName(QString::fromUtf8("btn_dial_EV"));
        sizePolicy.setHeightForWidth(btn_dial_EV->sizePolicy().hasHeightForWidth());
        btn_dial_EV->setSizePolicy(sizePolicy);
        btn_dial_EV->setStyleSheet(QString::fromUtf8("#upLeft { background-color: transparent; border-image: url(:/images/new/icon_safe.svg); background: none; border: none; background-repeat: none; }"));
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/images/new/icon_harddrive.svg"), QSize(), QIcon::Normal, QIcon::Off);
        btn_dial_EV->setIcon(icon2);

        gridLayout_5->addWidget(btn_dial_EV, 0, 1, 1, 1);

        btn_dial_HV = new QPushButton(groupBox_3);
        btn_dial_HV->setObjectName(QString::fromUtf8("btn_dial_HV"));
        sizePolicy.setHeightForWidth(btn_dial_HV->sizePolicy().hasHeightForWidth());
        btn_dial_HV->setSizePolicy(sizePolicy);
        btn_dial_HV->setStyleSheet(QString::fromUtf8("#upLeft { background-color: transparent; border-image: url(:/images/new/icon_safe.svg); background: none; border: none; background-repeat: none; }"));
        btn_dial_HV->setIcon(icon2);

        gridLayout_5->addWidget(btn_dial_HV, 0, 2, 1, 1);

        btn_dial_lock = new QPushButton(groupBox_3);
        btn_dial_lock->setObjectName(QString::fromUtf8("btn_dial_lock"));
        sizePolicy.setHeightForWidth(btn_dial_lock->sizePolicy().hasHeightForWidth());
        btn_dial_lock->setSizePolicy(sizePolicy);
        btn_dial_lock->setStyleSheet(QString::fromUtf8("#upLeft { background-color: transparent; border-image: url(:/images/new/icon_safe.svg); background: none; border: none; background-repeat: none; }"));
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/images/new/icon_unsafe.svg"), QSize(), QIcon::Normal, QIcon::Off);
        btn_dial_lock->setIcon(icon3);

        gridLayout_5->addWidget(btn_dial_lock, 1, 0, 1, 1);

        btn_dial_help = new QPushButton(groupBox_3);
        btn_dial_help->setObjectName(QString::fromUtf8("btn_dial_help"));
        sizePolicy.setHeightForWidth(btn_dial_help->sizePolicy().hasHeightForWidth());
        btn_dial_help->setSizePolicy(sizePolicy);
        btn_dial_help->setStyleSheet(QString::fromUtf8("#upLeft { background-color: transparent; border-image: url(:/images/new/icon_safe.svg); background: none; border: none; background-repeat: none; }"));
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/images/new/icon_fragezeichen.svg"), QSize(), QIcon::Normal, QIcon::Off);
        btn_dial_help->setIcon(icon4);

        gridLayout_5->addWidget(btn_dial_help, 1, 1, 1, 1);

        btn_dial_quit = new QPushButton(groupBox_3);
        btn_dial_quit->setObjectName(QString::fromUtf8("btn_dial_quit"));
        sizePolicy.setHeightForWidth(btn_dial_quit->sizePolicy().hasHeightForWidth());
        btn_dial_quit->setSizePolicy(sizePolicy);
        btn_dial_quit->setStyleSheet(QString::fromUtf8("#upLeft { background-color: transparent; border-image: url(:/images/new/icon_safe.svg); background: none; border: none; background-repeat: none; }"));
        QIcon icon5;
        icon5.addFile(QString::fromUtf8(":/images/new/icon_quit.svg"), QSize(), QIcon::Normal, QIcon::Off);
        btn_dial_quit->setIcon(icon5);

        gridLayout_5->addWidget(btn_dial_quit, 1, 2, 1, 1);


        gridLayout_6->addWidget(groupBox_3, 0, 0, 1, 1);

        tabWidget->addTab(tab_5, QString());
        tab = new QWidget();
        tab->setObjectName(QString::fromUtf8("tab"));
        verticalLayout_16 = new QVBoxLayout(tab);
        verticalLayout_16->setSpacing(6);
        verticalLayout_16->setContentsMargins(11, 11, 11, 11);
        verticalLayout_16->setObjectName(QString::fromUtf8("verticalLayout_16"));
        frame_8 = new QFrame(tab);
        frame_8->setObjectName(QString::fromUtf8("frame_8"));
        frame_8->setAutoFillBackground(false);
        frame_8->setFrameShape(QFrame::StyledPanel);
        frame_8->setFrameShadow(QFrame::Sunken);
        verticalLayout_11 = new QVBoxLayout(frame_8);
        verticalLayout_11->setSpacing(6);
        verticalLayout_11->setContentsMargins(11, 11, 11, 11);
        verticalLayout_11->setObjectName(QString::fromUtf8("verticalLayout_11"));
        label_24 = new QLabel(frame_8);
        label_24->setObjectName(QString::fromUtf8("label_24"));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        label_24->setFont(font);

        verticalLayout_11->addWidget(label_24);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setSpacing(6);
        horizontalLayout_14->setObjectName(QString::fromUtf8("horizontalLayout_14"));
        radioButton_2 = new QRadioButton(frame_8);
        radioButton_2->setObjectName(QString::fromUtf8("radioButton_2"));
        radioButton_2->setChecked(true);

        horizontalLayout_14->addWidget(radioButton_2);

        radioButton = new QRadioButton(frame_8);
        radioButton->setObjectName(QString::fromUtf8("radioButton"));

        horizontalLayout_14->addWidget(radioButton);

        label_25 = new QLabel(frame_8);
        label_25->setObjectName(QString::fromUtf8("label_25"));
        QFont font1;
        font1.setItalic(true);
        label_25->setFont(font1);

        horizontalLayout_14->addWidget(label_25);

        horizontalSpacer_14 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_14->addItem(horizontalSpacer_14);


        verticalLayout_11->addLayout(horizontalLayout_14);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setSpacing(6);
        horizontalLayout_9->setObjectName(QString::fromUtf8("horizontalLayout_9"));
        label = new QLabel(frame_8);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout_9->addWidget(label);

        slotComboBox = new QComboBox(frame_8);
        slotComboBox->addItem(QString::fromUtf8("HOTP slot"));
        slotComboBox->setObjectName(QString::fromUtf8("slotComboBox"));
        slotComboBox->setMinimumSize(QSize(300, 0));
        slotComboBox->setCurrentText(QString::fromUtf8("HOTP slot"));

        horizontalLayout_9->addWidget(slotComboBox);

        label_2 = new QLabel(frame_8);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        horizontalLayout_9->addWidget(label_2);

        nameEdit = new QLineEdit(frame_8);
        nameEdit->setObjectName(QString::fromUtf8("nameEdit"));
        nameEdit->setMaxLength(15);

        horizontalLayout_9->addWidget(nameEdit);

        eraseButton = new QPushButton(frame_8);
        eraseButton->setObjectName(QString::fromUtf8("eraseButton"));

        horizontalLayout_9->addWidget(eraseButton);


        verticalLayout_11->addLayout(horizontalLayout_9);


        verticalLayout_16->addWidget(frame_8);

        frame = new QFrame(tab);
        frame->setObjectName(QString::fromUtf8("frame"));
        frame->setAutoFillBackground(false);
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Sunken);
        verticalLayout_7 = new QVBoxLayout(frame);
        verticalLayout_7->setSpacing(6);
        verticalLayout_7->setContentsMargins(11, 11, 11, 11);
        verticalLayout_7->setObjectName(QString::fromUtf8("verticalLayout_7"));
        label_21 = new QLabel(frame);
        label_21->setObjectName(QString::fromUtf8("label_21"));
        label_21->setFont(font);

        verticalLayout_7->addWidget(label_21);

        formLayout_4 = new QFormLayout();
        formLayout_4->setSpacing(6);
        formLayout_4->setObjectName(QString::fromUtf8("formLayout_4"));
        formLayout_4->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        label_4 = new QLabel(frame);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        formLayout_4->setWidget(1, QFormLayout::LabelRole, label_4);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setSpacing(6);
        horizontalLayout_6->setObjectName(QString::fromUtf8("horizontalLayout_6"));
        base32RadioButton = new QRadioButton(frame);
        base32RadioButton->setObjectName(QString::fromUtf8("base32RadioButton"));
        base32RadioButton->setCheckable(true);
        base32RadioButton->setChecked(true);

        horizontalLayout_6->addWidget(base32RadioButton);

        hexRadioButton = new QRadioButton(frame);
        hexRadioButton->setObjectName(QString::fromUtf8("hexRadioButton"));
        hexRadioButton->setChecked(false);

        horizontalLayout_6->addWidget(hexRadioButton);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_2);

        l_supportedLength = new QLabel(frame);
        l_supportedLength->setObjectName(QString::fromUtf8("l_supportedLength"));
        QFont font2;
        font2.setPointSize(11);
        l_supportedLength->setFont(font2);

        horizontalLayout_6->addWidget(l_supportedLength);


        formLayout_4->setLayout(1, QFormLayout::FieldRole, horizontalLayout_6);

        label_3 = new QLabel(frame);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        formLayout_4->setWidget(2, QFormLayout::LabelRole, label_3);

        verticalLayout_6 = new QVBoxLayout();
        verticalLayout_6->setSpacing(6);
        verticalLayout_6->setObjectName(QString::fromUtf8("verticalLayout_6"));
        secretEdit = new QLineEdit(frame);
        secretEdit->setObjectName(QString::fromUtf8("secretEdit"));
        secretEdit->setMaxLength(200);
        secretEdit->setEchoMode(QLineEdit::PasswordEchoOnEdit);
        secretEdit->setClearButtonEnabled(false);

        verticalLayout_6->addWidget(secretEdit);

        labelNotify = new QLabel(frame);
        labelNotify->setObjectName(QString::fromUtf8("labelNotify"));
        QFont font3;
        font3.setPointSize(9);
        font3.setBold(true);
        font3.setItalic(true);
        font3.setWeight(75);
        labelNotify->setFont(font3);

        verticalLayout_6->addWidget(labelNotify);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(6);
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        checkBox = new QCheckBox(frame);
        checkBox->setObjectName(QString::fromUtf8("checkBox"));
        checkBox->setEnabled(true);
        checkBox->setChecked(true);

        horizontalLayout_4->addWidget(checkBox);

        horizontalSpacer_13 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_13);


        verticalLayout_6->addLayout(horizontalLayout_4);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(6);
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        label_7 = new QLabel(frame);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        horizontalLayout_3->addWidget(label_7);

        secret_key_generated_len = new QSpinBox(frame);
        secret_key_generated_len->setObjectName(QString::fromUtf8("secret_key_generated_len"));
        secret_key_generated_len->setMinimum(10);
        secret_key_generated_len->setMaximum(40);
        secret_key_generated_len->setValue(40);

        horizontalLayout_3->addWidget(secret_key_generated_len);

        randomSecretButton = new QPushButton(frame);
        randomSecretButton->setObjectName(QString::fromUtf8("randomSecretButton"));

        horizontalLayout_3->addWidget(randomSecretButton);

        btn_copyToClipboard = new QPushButton(frame);
        btn_copyToClipboard->setObjectName(QString::fromUtf8("btn_copyToClipboard"));

        horizontalLayout_3->addWidget(btn_copyToClipboard);


        verticalLayout_6->addLayout(horizontalLayout_3);


        formLayout_4->setLayout(2, QFormLayout::FieldRole, verticalLayout_6);


        verticalLayout_7->addLayout(formLayout_4);

        label_26 = new QLabel(frame);
        label_26->setObjectName(QString::fromUtf8("label_26"));
        QFont font4;
        font4.setPointSize(11);
        font4.setItalic(true);
        label_26->setFont(font4);
        label_26->setWordWrap(true);

        verticalLayout_7->addWidget(label_26);


        verticalLayout_16->addWidget(frame);

        frame_2 = new QFrame(tab);
        frame_2->setObjectName(QString::fromUtf8("frame_2"));
        frame_2->setAutoFillBackground(false);
        frame_2->setFrameShape(QFrame::StyledPanel);
        frame_2->setFrameShadow(QFrame::Sunken);
        verticalLayout_9 = new QVBoxLayout(frame_2);
        verticalLayout_9->setSpacing(6);
        verticalLayout_9->setContentsMargins(11, 11, 11, 11);
        verticalLayout_9->setObjectName(QString::fromUtf8("verticalLayout_9"));
        label_22 = new QLabel(frame_2);
        label_22->setObjectName(QString::fromUtf8("label_22"));
        label_22->setFont(font);

        verticalLayout_9->addWidget(label_22);

        formLayout_5 = new QFormLayout();
        formLayout_5->setSpacing(6);
        formLayout_5->setObjectName(QString::fromUtf8("formLayout_5"));
        formLayout_5->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setSpacing(6);
        verticalLayout_5->setObjectName(QString::fromUtf8("verticalLayout_5"));
        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setSpacing(6);
        horizontalLayout_7->setObjectName(QString::fromUtf8("horizontalLayout_7"));
        counterEdit = new QLineEdit(frame_2);
        counterEdit->setObjectName(QString::fromUtf8("counterEdit"));
        counterEdit->setMaxLength(20);

        horizontalLayout_7->addWidget(counterEdit);

        setToZeroButton = new QPushButton(frame_2);
        setToZeroButton->setObjectName(QString::fromUtf8("setToZeroButton"));

        horizontalLayout_7->addWidget(setToZeroButton);

        setToRandomButton = new QPushButton(frame_2);
        setToRandomButton->setObjectName(QString::fromUtf8("setToRandomButton"));

        horizontalLayout_7->addWidget(setToRandomButton);


        verticalLayout_5->addLayout(horizontalLayout_7);


        formLayout_5->setLayout(4, QFormLayout::FieldRole, verticalLayout_5);

        verticalSpacer_3 = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        formLayout_5->setItem(5, QFormLayout::FieldRole, verticalSpacer_3);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setSpacing(6);
        horizontalLayout_8->setObjectName(QString::fromUtf8("horizontalLayout_8"));
        digits6radioButton = new QRadioButton(frame_2);
        digits6radioButton->setObjectName(QString::fromUtf8("digits6radioButton"));
        digits6radioButton->setChecked(true);

        horizontalLayout_8->addWidget(digits6radioButton);

        digits8radioButton = new QRadioButton(frame_2);
        digits8radioButton->setObjectName(QString::fromUtf8("digits8radioButton"));

        horizontalLayout_8->addWidget(digits8radioButton);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_6);


        formLayout_5->setLayout(3, QFormLayout::FieldRole, horizontalLayout_8);

        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setSpacing(6);
        horizontalLayout_15->setObjectName(QString::fromUtf8("horizontalLayout_15"));
        intervalSpinBox = new QSpinBox(frame_2);
        intervalSpinBox->setObjectName(QString::fromUtf8("intervalSpinBox"));
        intervalSpinBox->setMinimum(1);
        intervalSpinBox->setMaximum(65536);
        intervalSpinBox->setValue(30);

        horizontalLayout_15->addWidget(intervalSpinBox);

        horizontalSpacer_10 = new QSpacerItem(40, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_15->addItem(horizontalSpacer_10);


        formLayout_5->setLayout(2, QFormLayout::FieldRole, horizontalLayout_15);

        label_6 = new QLabel(frame_2);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        formLayout_5->setWidget(4, QFormLayout::LabelRole, label_6);

        label_5 = new QLabel(frame_2);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        formLayout_5->setWidget(3, QFormLayout::LabelRole, label_5);

        intervalLabel = new QLabel(frame_2);
        intervalLabel->setObjectName(QString::fromUtf8("intervalLabel"));

        formLayout_5->setWidget(2, QFormLayout::LabelRole, intervalLabel);


        verticalLayout_9->addLayout(formLayout_5);


        verticalLayout_16->addWidget(frame_2);

        verticalSpacer = new QSpacerItem(20, 1, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        verticalLayout_16->addItem(verticalSpacer);

        line = new QFrame(tab);
        line->setObjectName(QString::fromUtf8("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        verticalLayout_16->addWidget(line);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        progressBar = new QProgressBar(tab);
        progressBar->setObjectName(QString::fromUtf8("progressBar"));
        progressBar->setValue(24);

        horizontalLayout->addWidget(progressBar);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        cancelButton = new QPushButton(tab);
        cancelButton->setObjectName(QString::fromUtf8("cancelButton"));

        horizontalLayout->addWidget(cancelButton);

        writeButton = new QPushButton(tab);
        writeButton->setObjectName(QString::fromUtf8("writeButton"));

        horizontalLayout->addWidget(writeButton);


        verticalLayout_16->addLayout(horizontalLayout);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName(QString::fromUtf8("tab_2"));
        verticalLayout_14 = new QVBoxLayout(tab_2);
        verticalLayout_14->setSpacing(6);
        verticalLayout_14->setContentsMargins(11, 11, 11, 11);
        verticalLayout_14->setObjectName(QString::fromUtf8("verticalLayout_14"));
        frame_4 = new QFrame(tab_2);
        frame_4->setObjectName(QString::fromUtf8("frame_4"));
        frame_4->setAutoFillBackground(false);
        frame_4->setFrameShape(QFrame::StyledPanel);
        frame_4->setFrameShadow(QFrame::Sunken);
        verticalLayout_12 = new QVBoxLayout(frame_4);
        verticalLayout_12->setSpacing(6);
        verticalLayout_12->setContentsMargins(11, 11, 11, 11);
        verticalLayout_12->setObjectName(QString::fromUtf8("verticalLayout_12"));
        label_11 = new QLabel(frame_4);
        label_11->setObjectName(QString::fromUtf8("label_11"));
        label_11->setFont(font);

        verticalLayout_12->addWidget(label_11);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setSpacing(6);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        enableUserPasswordCheckBox = new QCheckBox(frame_4);
        enableUserPasswordCheckBox->setObjectName(QString::fromUtf8("enableUserPasswordCheckBox"));

        verticalLayout_2->addWidget(enableUserPasswordCheckBox);

        deleteUserPasswordCheckBox = new QCheckBox(frame_4);
        deleteUserPasswordCheckBox->setObjectName(QString::fromUtf8("deleteUserPasswordCheckBox"));

        verticalLayout_2->addWidget(deleteUserPasswordCheckBox);


        verticalLayout_12->addLayout(verticalLayout_2);


        verticalLayout_14->addWidget(frame_4);

        verticalSpacer_2 = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        verticalLayout_14->addItem(verticalSpacer_2);

        line_2 = new QFrame(tab_2);
        line_2->setObjectName(QString::fromUtf8("line_2"));
        line_2->setFrameShape(QFrame::HLine);
        line_2->setFrameShadow(QFrame::Sunken);

        verticalLayout_14->addWidget(line_2);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setSpacing(6);
        horizontalLayout_5->setObjectName(QString::fromUtf8("horizontalLayout_5"));
        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_4);

        generalCancelButton = new QPushButton(tab_2);
        generalCancelButton->setObjectName(QString::fromUtf8("generalCancelButton"));

        horizontalLayout_5->addWidget(generalCancelButton);

        writeGeneralConfigButton = new QPushButton(tab_2);
        writeGeneralConfigButton->setObjectName(QString::fromUtf8("writeGeneralConfigButton"));

        horizontalLayout_5->addWidget(writeGeneralConfigButton);


        verticalLayout_14->addLayout(horizontalLayout_5);

        tabWidget->addTab(tab_2, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName(QString::fromUtf8("tab_3"));
        verticalLayout_19 = new QVBoxLayout(tab_3);
        verticalLayout_19->setSpacing(6);
        verticalLayout_19->setContentsMargins(11, 11, 11, 11);
        verticalLayout_19->setObjectName(QString::fromUtf8("verticalLayout_19"));
        frame_7 = new QFrame(tab_3);
        frame_7->setObjectName(QString::fromUtf8("frame_7"));
        QSizePolicy sizePolicy2(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(frame_7->sizePolicy().hasHeightForWidth());
        frame_7->setSizePolicy(sizePolicy2);
        frame_7->setAutoFillBackground(false);
        frame_7->setFrameShape(QFrame::StyledPanel);
        frame_7->setFrameShadow(QFrame::Sunken);
        verticalLayout_18 = new QVBoxLayout(frame_7);
        verticalLayout_18->setSpacing(6);
        verticalLayout_18->setContentsMargins(11, 11, 11, 11);
        verticalLayout_18->setObjectName(QString::fromUtf8("verticalLayout_18"));
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        PWS_EditPassword = new QLineEdit(frame_7);
        PWS_EditPassword->setObjectName(QString::fromUtf8("PWS_EditPassword"));

        gridLayout->addWidget(PWS_EditPassword, 3, 1, 1, 1);

        PWS_EditLoginName = new QLineEdit(frame_7);
        PWS_EditLoginName->setObjectName(QString::fromUtf8("PWS_EditLoginName"));

        gridLayout->addWidget(PWS_EditLoginName, 2, 1, 1, 1);

        label_19 = new QLabel(frame_7);
        label_19->setObjectName(QString::fromUtf8("label_19"));

        gridLayout->addWidget(label_19, 3, 0, 1, 1);

        PWS_EditSlotName = new QLineEdit(frame_7);
        PWS_EditSlotName->setObjectName(QString::fromUtf8("PWS_EditSlotName"));

        gridLayout->addWidget(PWS_EditSlotName, 1, 1, 1, 1);

        label_18 = new QLabel(frame_7);
        label_18->setObjectName(QString::fromUtf8("label_18"));

        gridLayout->addWidget(label_18, 2, 0, 1, 1);

        PWS_ButtonClearSlot = new QPushButton(frame_7);
        PWS_ButtonClearSlot->setObjectName(QString::fromUtf8("PWS_ButtonClearSlot"));

        gridLayout->addWidget(PWS_ButtonClearSlot, 0, 3, 1, 1);

        label_17 = new QLabel(frame_7);
        label_17->setObjectName(QString::fromUtf8("label_17"));

        gridLayout->addWidget(label_17, 1, 0, 1, 1);

        PWS_ComboBoxSelectSlot = new QComboBox(frame_7);
        PWS_ComboBoxSelectSlot->addItem(QString());
        PWS_ComboBoxSelectSlot->setObjectName(QString::fromUtf8("PWS_ComboBoxSelectSlot"));
        PWS_ComboBoxSelectSlot->setCurrentText(QString::fromUtf8("Static password 0"));

        gridLayout->addWidget(PWS_ComboBoxSelectSlot, 0, 1, 1, 1);

        PWS_ButtonCreatePW = new QPushButton(frame_7);
        PWS_ButtonCreatePW->setObjectName(QString::fromUtf8("PWS_ButtonCreatePW"));

        gridLayout->addWidget(PWS_ButtonCreatePW, 3, 3, 1, 1);

        label_16 = new QLabel(frame_7);
        label_16->setObjectName(QString::fromUtf8("label_16"));

        gridLayout->addWidget(label_16, 0, 0, 1, 1);

        PWS_CheckBoxHideSecret = new QCheckBox(frame_7);
        PWS_CheckBoxHideSecret->setObjectName(QString::fromUtf8("PWS_CheckBoxHideSecret"));
        PWS_CheckBoxHideSecret->setEnabled(true);
        PWS_CheckBoxHideSecret->setChecked(true);

        gridLayout->addWidget(PWS_CheckBoxHideSecret, 4, 1, 1, 1);

        l_chars_left_info = new QLabel(frame_7);
        l_chars_left_info->setObjectName(QString::fromUtf8("l_chars_left_info"));

        gridLayout->addWidget(l_chars_left_info, 0, 2, 1, 1);

        l_c_name = new QLabel(frame_7);
        l_c_name->setObjectName(QString::fromUtf8("l_c_name"));
        l_c_name->setText(QString::fromUtf8("..."));
        l_c_name->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(l_c_name, 1, 2, 1, 1);

        l_c_login = new QLabel(frame_7);
        l_c_login->setObjectName(QString::fromUtf8("l_c_login"));
        l_c_login->setText(QString::fromUtf8("..."));
        l_c_login->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(l_c_login, 2, 2, 1, 1);

        l_c_password = new QLabel(frame_7);
        l_c_password->setObjectName(QString::fromUtf8("l_c_password"));
        l_c_password->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(l_c_password, 3, 2, 1, 1);


        verticalLayout_18->addLayout(gridLayout);


        verticalLayout_19->addWidget(frame_7);

        l_utf8_info = new QLabel(tab_3);
        l_utf8_info->setObjectName(QString::fromUtf8("l_utf8_info"));
        l_utf8_info->setFocusPolicy(Qt::StrongFocus);
        l_utf8_info->setWordWrap(true);

        verticalLayout_19->addWidget(l_utf8_info);

        verticalSpacer_9 = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        verticalLayout_19->addItem(verticalSpacer_9);

        line_3 = new QFrame(tab_3);
        line_3->setObjectName(QString::fromUtf8("line_3"));
        line_3->setFrameShape(QFrame::HLine);
        line_3->setFrameShadow(QFrame::Sunken);

        verticalLayout_19->addWidget(line_3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(6);
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        PWS_ButtonEnable = new QPushButton(tab_3);
        PWS_ButtonEnable->setObjectName(QString::fromUtf8("PWS_ButtonEnable"));

        horizontalLayout_2->addWidget(PWS_ButtonEnable);

        PWS_Lock = new QPushButton(tab_3);
        PWS_Lock->setObjectName(QString::fromUtf8("PWS_Lock"));

        horizontalLayout_2->addWidget(PWS_Lock);

        PWS_progressBar = new QProgressBar(tab_3);
        PWS_progressBar->setObjectName(QString::fromUtf8("PWS_progressBar"));
        PWS_progressBar->setValue(42);

        horizontalLayout_2->addWidget(PWS_progressBar);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);

        PWS_ButtonClose = new QPushButton(tab_3);
        PWS_ButtonClose->setObjectName(QString::fromUtf8("PWS_ButtonClose"));

        horizontalLayout_2->addWidget(PWS_ButtonClose);

        PWS_ButtonSaveSlot = new QPushButton(tab_3);
        PWS_ButtonSaveSlot->setObjectName(QString::fromUtf8("PWS_ButtonSaveSlot"));
        PWS_ButtonSaveSlot->setAutoDefault(true);

        horizontalLayout_2->addWidget(PWS_ButtonSaveSlot);


        verticalLayout_19->addLayout(horizontalLayout_2);

        tabWidget->addTab(tab_3, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName(QString::fromUtf8("tab_4"));
        verticalLayout_73 = new QVBoxLayout(tab_4);
        verticalLayout_73->setSpacing(6);
        verticalLayout_73->setContentsMargins(11, 11, 11, 11);
        verticalLayout_73->setObjectName(QString::fromUtf8("verticalLayout_73"));
        verticalLayout_72 = new QVBoxLayout();
        verticalLayout_72->setSpacing(6);
        verticalLayout_72->setObjectName(QString::fromUtf8("verticalLayout_72"));
        frame_9 = new QFrame(tab_4);
        frame_9->setObjectName(QString::fromUtf8("frame_9"));
        frame_9->setFrameShape(QFrame::StyledPanel);
        frame_9->setFrameShadow(QFrame::Raised);
        verticalLayout_15 = new QVBoxLayout(frame_9);
        verticalLayout_15->setSpacing(6);
        verticalLayout_15->setContentsMargins(11, 11, 11, 11);
        verticalLayout_15->setObjectName(QString::fromUtf8("verticalLayout_15"));
        gr_general = new QGroupBox(frame_9);
        gr_general->setObjectName(QString::fromUtf8("gr_general"));
        verticalLayout_3 = new QVBoxLayout(gr_general);
        verticalLayout_3->setSpacing(6);
        verticalLayout_3->setContentsMargins(11, 11, 11, 11);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        horizontalLayout_19 = new QHBoxLayout();
        horizontalLayout_19->setSpacing(6);
        horizontalLayout_19->setObjectName(QString::fromUtf8("horizontalLayout_19"));
        cb_first_run_message = new QCheckBox(gr_general);
        cb_first_run_message->setObjectName(QString::fromUtf8("cb_first_run_message"));

        horizontalLayout_19->addWidget(cb_first_run_message);

        cb_show_window_on_start = new QCheckBox(gr_general);
        cb_show_window_on_start->setObjectName(QString::fromUtf8("cb_show_window_on_start"));

        horizontalLayout_19->addWidget(cb_show_window_on_start);


        verticalLayout_3->addLayout(horizontalLayout_19);

        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setSpacing(6);
        horizontalLayout_17->setObjectName(QString::fromUtf8("horizontalLayout_17"));
        cb_hide_main_window_on_close = new QCheckBox(gr_general);
        cb_hide_main_window_on_close->setObjectName(QString::fromUtf8("cb_hide_main_window_on_close"));
        cb_hide_main_window_on_close->setChecked(true);

        horizontalLayout_17->addWidget(cb_hide_main_window_on_close);

        cb_hide_main_window_on_connection = new QCheckBox(gr_general);
        cb_hide_main_window_on_connection->setObjectName(QString::fromUtf8("cb_hide_main_window_on_connection"));
        cb_hide_main_window_on_connection->setChecked(true);

        horizontalLayout_17->addWidget(cb_hide_main_window_on_connection);


        verticalLayout_3->addLayout(horizontalLayout_17);

        cb_show_main_window_on_connection = new QCheckBox(gr_general);
        cb_show_main_window_on_connection->setObjectName(QString::fromUtf8("cb_show_main_window_on_connection"));
        cb_show_main_window_on_connection->setChecked(true);

        verticalLayout_3->addWidget(cb_show_main_window_on_connection);

        cb_check_symlink = new QCheckBox(gr_general);
        cb_check_symlink->setObjectName(QString::fromUtf8("cb_check_symlink"));
        cb_check_symlink->setChecked(true);

        verticalLayout_3->addWidget(cb_check_symlink);

        cb_device_connection_message = new QCheckBox(gr_general);
        cb_device_connection_message->setObjectName(QString::fromUtf8("cb_device_connection_message"));
        cb_device_connection_message->setChecked(true);

        verticalLayout_3->addWidget(cb_device_connection_message);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setSpacing(6);
        horizontalLayout_12->setObjectName(QString::fromUtf8("horizontalLayout_12"));
        label_28 = new QLabel(gr_general);
        label_28->setObjectName(QString::fromUtf8("label_28"));

        horizontalLayout_12->addWidget(label_28);

        combo_languages = new QComboBox(gr_general);
        combo_languages->setObjectName(QString::fromUtf8("combo_languages"));

        horizontalLayout_12->addWidget(combo_languages);


        verticalLayout_3->addLayout(horizontalLayout_12);


        verticalLayout_15->addWidget(gr_general);


        verticalLayout_72->addWidget(frame_9);

        verticalLayout_71 = new QVBoxLayout();
        verticalLayout_71->setSpacing(6);
        verticalLayout_71->setObjectName(QString::fromUtf8("verticalLayout_71"));
        groupBox = new QGroupBox(tab_4);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout_3 = new QGridLayout(groupBox);
        gridLayout_3->setSpacing(6);
        gridLayout_3->setContentsMargins(11, 11, 11, 11);
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        edit_debug_file_path = new QLineEdit(groupBox);
        edit_debug_file_path->setObjectName(QString::fromUtf8("edit_debug_file_path"));

        gridLayout_3->addWidget(edit_debug_file_path, 1, 1, 1, 1);

        spin_debug_verbosity = new QSpinBox(groupBox);
        spin_debug_verbosity->setObjectName(QString::fromUtf8("spin_debug_verbosity"));
        spin_debug_verbosity->setMaximum(6);
        spin_debug_verbosity->setValue(2);

        gridLayout_3->addWidget(spin_debug_verbosity, 3, 1, 1, 1);

        label_10 = new QLabel(groupBox);
        label_10->setObjectName(QString::fromUtf8("label_10"));

        gridLayout_3->addWidget(label_10, 1, 0, 1, 1);

        label_20 = new QLabel(groupBox);
        label_20->setObjectName(QString::fromUtf8("label_20"));

        gridLayout_3->addWidget(label_20, 3, 0, 1, 1);

        cb_debug_enabled = new QCheckBox(groupBox);
        cb_debug_enabled->setObjectName(QString::fromUtf8("cb_debug_enabled"));

        gridLayout_3->addWidget(cb_debug_enabled, 0, 0, 1, 1);

        btn_select_debug_console = new QPushButton(groupBox);
        btn_select_debug_console->setObjectName(QString::fromUtf8("btn_select_debug_console"));

        gridLayout_3->addWidget(btn_select_debug_console, 1, 2, 1, 1);

        btn_select_debug_file_path = new QPushButton(groupBox);
        btn_select_debug_file_path->setObjectName(QString::fromUtf8("btn_select_debug_file_path"));

        gridLayout_3->addWidget(btn_select_debug_file_path, 1, 3, 1, 1);


        verticalLayout_71->addWidget(groupBox);

        groupBox_2 = new QGroupBox(tab_4);
        groupBox_2->setObjectName(QString::fromUtf8("groupBox_2"));
        gridLayout_4 = new QGridLayout(groupBox_2);
        gridLayout_4->setSpacing(6);
        gridLayout_4->setContentsMargins(11, 11, 11, 11);
        gridLayout_4->setObjectName(QString::fromUtf8("gridLayout_4"));
        spin_OTP_time = new QSpinBox(groupBox_2);
        spin_OTP_time->setObjectName(QString::fromUtf8("spin_OTP_time"));
        spin_OTP_time->setMinimum(10);
        spin_OTP_time->setMaximum(600);
        spin_OTP_time->setValue(120);

        gridLayout_4->addWidget(spin_OTP_time, 3, 1, 1, 1);

        label_30 = new QLabel(groupBox_2);
        label_30->setObjectName(QString::fromUtf8("label_30"));

        gridLayout_4->addWidget(label_30, 1, 0, 1, 1);

        spin_PWS_time = new QSpinBox(groupBox_2);
        spin_PWS_time->setObjectName(QString::fromUtf8("spin_PWS_time"));
        spin_PWS_time->setMinimum(10);
        spin_PWS_time->setMaximum(600);
        spin_PWS_time->setValue(60);

        gridLayout_4->addWidget(spin_PWS_time, 1, 1, 1, 1);

        label_31 = new QLabel(groupBox_2);
        label_31->setObjectName(QString::fromUtf8("label_31"));

        gridLayout_4->addWidget(label_31, 3, 0, 1, 1);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_4->addItem(horizontalSpacer_7, 1, 2, 1, 1);


        verticalLayout_71->addWidget(groupBox_2);

        verticalSpacer_4 = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        verticalLayout_71->addItem(verticalSpacer_4);

        line_10 = new QFrame(tab_4);
        line_10->setObjectName(QString::fromUtf8("line_10"));
        line_10->setFrameShape(QFrame::HLine);
        line_10->setFrameShadow(QFrame::Sunken);

        verticalLayout_71->addWidget(line_10);


        verticalLayout_72->addLayout(verticalLayout_71);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setSpacing(6);
        horizontalLayout_11->setObjectName(QString::fromUtf8("horizontalLayout_11"));
        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_11->addItem(horizontalSpacer_5);

        btn_cancelSettings = new QPushButton(tab_4);
        btn_cancelSettings->setObjectName(QString::fromUtf8("btn_cancelSettings"));

        horizontalLayout_11->addWidget(btn_cancelSettings);

        btn_writeSettings = new QPushButton(tab_4);
        btn_writeSettings->setObjectName(QString::fromUtf8("btn_writeSettings"));

        horizontalLayout_11->addWidget(btn_writeSettings);


        verticalLayout_72->addLayout(horizontalLayout_11);


        verticalLayout_73->addLayout(verticalLayout_72);

        tabWidget->addTab(tab_4, QString());

        verticalLayout->addWidget(tabWidget);

        MainWindow->setCentralWidget(centralWidget);
        statusBar = new QStatusBar(MainWindow);
        statusBar->setObjectName(QString::fromUtf8("statusBar"));
        statusBar->setSizeGripEnabled(false);
        MainWindow->setStatusBar(statusBar);
        menuBar = new QMenuBar(MainWindow);
        menuBar->setObjectName(QString::fromUtf8("menuBar"));
        menuBar->setGeometry(QRect(0, 0, 932, 27));
        MainWindow->setMenuBar(menuBar);
#if QT_CONFIG(shortcut)
        label_10->setBuddy(edit_debug_file_path);
        label_20->setBuddy(spin_debug_verbosity);
        label_30->setBuddy(spin_debug_verbosity);
        label_31->setBuddy(spin_debug_verbosity);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(btn_dial_PWS, btn_dial_EV);
        QWidget::setTabOrder(btn_dial_EV, btn_dial_HV);
        QWidget::setTabOrder(btn_dial_HV, btn_dial_lock);
        QWidget::setTabOrder(btn_dial_lock, btn_dial_help);
        QWidget::setTabOrder(btn_dial_help, btn_dial_quit);
        QWidget::setTabOrder(btn_dial_quit, radioButton_2);
        QWidget::setTabOrder(radioButton_2, radioButton);
        QWidget::setTabOrder(radioButton, slotComboBox);
        QWidget::setTabOrder(slotComboBox, nameEdit);
        QWidget::setTabOrder(nameEdit, eraseButton);
        QWidget::setTabOrder(eraseButton, base32RadioButton);
        QWidget::setTabOrder(base32RadioButton, hexRadioButton);
        QWidget::setTabOrder(hexRadioButton, secretEdit);
        QWidget::setTabOrder(secretEdit, checkBox);
        QWidget::setTabOrder(checkBox, intervalSpinBox);
        QWidget::setTabOrder(intervalSpinBox, digits6radioButton);
        QWidget::setTabOrder(digits6radioButton, digits8radioButton);
        QWidget::setTabOrder(digits8radioButton, counterEdit);
        QWidget::setTabOrder(counterEdit, setToZeroButton);
        QWidget::setTabOrder(setToZeroButton, setToRandomButton);
        QWidget::setTabOrder(setToRandomButton, cancelButton);
        QWidget::setTabOrder(cancelButton, writeButton);
        QWidget::setTabOrder(writeButton, enableUserPasswordCheckBox);
        QWidget::setTabOrder(enableUserPasswordCheckBox, deleteUserPasswordCheckBox);
        QWidget::setTabOrder(deleteUserPasswordCheckBox, PWS_ComboBoxSelectSlot);
        QWidget::setTabOrder(PWS_ComboBoxSelectSlot, PWS_ButtonClearSlot);
        QWidget::setTabOrder(PWS_ButtonClearSlot, PWS_EditSlotName);
        QWidget::setTabOrder(PWS_EditSlotName, PWS_EditLoginName);
        QWidget::setTabOrder(PWS_EditLoginName, PWS_EditPassword);
        QWidget::setTabOrder(PWS_EditPassword, PWS_ButtonCreatePW);
        QWidget::setTabOrder(PWS_ButtonCreatePW, PWS_CheckBoxHideSecret);
        QWidget::setTabOrder(PWS_CheckBoxHideSecret, l_utf8_info);
        QWidget::setTabOrder(l_utf8_info, PWS_ButtonEnable);
        QWidget::setTabOrder(PWS_ButtonEnable, PWS_Lock);
        QWidget::setTabOrder(PWS_Lock, PWS_ButtonClose);
        QWidget::setTabOrder(PWS_ButtonClose, PWS_ButtonSaveSlot);
        QWidget::setTabOrder(PWS_ButtonSaveSlot, cb_first_run_message);
        QWidget::setTabOrder(cb_first_run_message, cb_show_window_on_start);
        QWidget::setTabOrder(cb_show_window_on_start, cb_check_symlink);
        QWidget::setTabOrder(cb_check_symlink, cb_device_connection_message);
        QWidget::setTabOrder(cb_device_connection_message, cb_show_main_window_on_connection);
        QWidget::setTabOrder(cb_show_main_window_on_connection, cb_hide_main_window_on_connection);
        QWidget::setTabOrder(cb_hide_main_window_on_connection, cb_hide_main_window_on_close);
        QWidget::setTabOrder(cb_hide_main_window_on_close, combo_languages);
        QWidget::setTabOrder(combo_languages, cb_debug_enabled);
        QWidget::setTabOrder(cb_debug_enabled, edit_debug_file_path);
        QWidget::setTabOrder(edit_debug_file_path, btn_select_debug_console);
        QWidget::setTabOrder(btn_select_debug_console, btn_select_debug_file_path);
        QWidget::setTabOrder(btn_select_debug_file_path, spin_debug_verbosity);
        QWidget::setTabOrder(spin_debug_verbosity, spin_PWS_time);
        QWidget::setTabOrder(spin_PWS_time, spin_OTP_time);
        QWidget::setTabOrder(spin_OTP_time, btn_cancelSettings);
        QWidget::setTabOrder(btn_cancelSettings, btn_writeSettings);
        QWidget::setTabOrder(btn_writeSettings, writeGeneralConfigButton);
        QWidget::setTabOrder(writeGeneralConfigButton, generalCancelButton);
        QWidget::setTabOrder(generalCancelButton, tabWidget);
        QWidget::setTabOrder(tabWidget, secret_key_generated_len);
        QWidget::setTabOrder(secret_key_generated_len, randomSecretButton);
        QWidget::setTabOrder(randomSecretButton, btn_copyToClipboard);

        retranslateUi(MainWindow);
        QObject::connect(generalCancelButton, SIGNAL(clicked()), MainWindow, SLOT(hide()));
        QObject::connect(cancelButton, SIGNAL(clicked()), MainWindow, SLOT(hide()));
        QObject::connect(btn_cancelSettings, SIGNAL(clicked()), MainWindow, SLOT(hide()));
        QObject::connect(cb_debug_enabled, SIGNAL(toggled(bool)), edit_debug_file_path, SLOT(setEnabled(bool)));
        QObject::connect(cb_debug_enabled, SIGNAL(toggled(bool)), spin_debug_verbosity, SLOT(setEnabled(bool)));
        QObject::connect(cb_debug_enabled, SIGNAL(toggled(bool)), btn_select_debug_file_path, SLOT(setEnabled(bool)));
        QObject::connect(cb_debug_enabled, SIGNAL(toggled(bool)), btn_select_debug_console, SLOT(setEnabled(bool)));

        tabWidget->setCurrentIndex(4);
        slotComboBox->setCurrentIndex(0);
        PWS_ComboBoxSelectSlot->setCurrentIndex(0);
        PWS_ButtonSaveSlot->setDefault(true);


        QMetaObject::connectSlotsByName(MainWindow);
    } // setupUi

    void retranslateUi(QMainWindow *MainWindow)
    {
        MainWindow->setWindowTitle(QCoreApplication::translate("MainWindow", "Nitrokey App", nullptr));
        groupBox_3->setTitle(QString());
        btn_dial_PWS->setText(QCoreApplication::translate("MainWindow", "Unlock Password Safe", nullptr));
        btn_dial_EV->setText(QCoreApplication::translate("MainWindow", "Unlock Encrypted Volume", nullptr));
        btn_dial_HV->setText(QCoreApplication::translate("MainWindow", "Unlock Hidden Volume", nullptr));
        btn_dial_lock->setText(QCoreApplication::translate("MainWindow", "Lock Device", nullptr));
        btn_dial_help->setText(QCoreApplication::translate("MainWindow", "Help", nullptr));
        btn_dial_quit->setText(QCoreApplication::translate("MainWindow", "Quit", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_5), QCoreApplication::translate("MainWindow", "Overview", nullptr));
        label_24->setText(QCoreApplication::translate("MainWindow", "Manage slots", nullptr));
#if QT_CONFIG(accessibility)
        radioButton_2->setAccessibleName(QCoreApplication::translate("MainWindow", "Select slot type: TOTP", nullptr));
#endif // QT_CONFIG(accessibility)
#if QT_CONFIG(accessibility)
        radioButton_2->setAccessibleDescription(QCoreApplication::translate("MainWindow", "(Recommendation: Use TOTP for web applications and HOTP for local applications)", nullptr));
#endif // QT_CONFIG(accessibility)
        radioButton_2->setText(QCoreApplication::translate("MainWindow", "TOTP", nullptr));
#if QT_CONFIG(accessibility)
        radioButton->setAccessibleName(QCoreApplication::translate("MainWindow", "Select slot type: HOTP", nullptr));
#endif // QT_CONFIG(accessibility)
#if QT_CONFIG(accessibility)
        radioButton->setAccessibleDescription(QCoreApplication::translate("MainWindow", "(Recommendation: Use TOTP for web applications and HOTP for local applications)", nullptr));
#endif // QT_CONFIG(accessibility)
        radioButton->setText(QCoreApplication::translate("MainWindow", "HOTP", nullptr));
        label_25->setText(QCoreApplication::translate("MainWindow", "(Recommendation: Use TOTP for web applications and HOTP for local applications)", nullptr));
        label->setText(QCoreApplication::translate("MainWindow", "Slot:", nullptr));

#if QT_CONFIG(accessibility)
        slotComboBox->setAccessibleName(QCoreApplication::translate("MainWindow", "Select OTP slot number", nullptr));
#endif // QT_CONFIG(accessibility)
        label_2->setText(QCoreApplication::translate("MainWindow", "Name:", nullptr));
#if QT_CONFIG(accessibility)
        nameEdit->setAccessibleName(QCoreApplication::translate("MainWindow", "Slot name", nullptr));
#endif // QT_CONFIG(accessibility)
        nameEdit->setInputMask(QString());
        eraseButton->setText(QCoreApplication::translate("MainWindow", "Erase Slot", nullptr));
        label_21->setText(QCoreApplication::translate("MainWindow", "Secret key", nullptr));
        label_4->setText(QCoreApplication::translate("MainWindow", "Input format:", nullptr));
#if QT_CONFIG(tooltip)
        base32RadioButton->setToolTip(QCoreApplication::translate("MainWindow", "Example: \"ZR3M5I...\"", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(accessibility)
        base32RadioButton->setAccessibleName(QCoreApplication::translate("MainWindow", "Secret input format: base32", nullptr));
#endif // QT_CONFIG(accessibility)
        base32RadioButton->setText(QCoreApplication::translate("MainWindow", "Base32", nullptr));
#if QT_CONFIG(tooltip)
        hexRadioButton->setToolTip(QCoreApplication::translate("MainWindow", "Example: \"A3911C05...\" (remove any 0x prefix)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(accessibility)
        hexRadioButton->setAccessibleName(QCoreApplication::translate("MainWindow", "Secret input format: hex", nullptr));
#endif // QT_CONFIG(accessibility)
        hexRadioButton->setText(QCoreApplication::translate("MainWindow", "Hex", nullptr));
#if QT_CONFIG(accessibility)
        l_supportedLength->setAccessibleName(QCoreApplication::translate("MainWindow", "Entered OTP 'Secret Key' string is longer than supported by this device", nullptr));
#endif // QT_CONFIG(accessibility)
#if QT_CONFIG(accessibility)
        l_supportedLength->setAccessibleDescription(QCoreApplication::translate("MainWindow", "Label shown when the OTP secret key is too long", nullptr));
#endif // QT_CONFIG(accessibility)
        l_supportedLength->setText(QCoreApplication::translate("MainWindow", "<html><head/><body><p><span style=\" font-weight:600; color:#a40000;\">Entered OTP 'Secret Key' string is longer than supported by this device</span></p></body></html>", nullptr));
#if QT_CONFIG(tooltip)
        label_3->setToolTip(QCoreApplication::translate("MainWindow", "<html><head/><body><p>The secret is provided by your service provider you may want to login or can be configured in your local application which you may want to login to.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(QCoreApplication::translate("MainWindow", "Secret Key:", nullptr));
#if QT_CONFIG(tooltip)
        secretEdit->setToolTip(QCoreApplication::translate("MainWindow", "The secret is provided by your service provider you may want to login or can be configured in your local application which you may want to login to.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(accessibility)
        secretEdit->setAccessibleName(QCoreApplication::translate("MainWindow", "OTP secret key", nullptr));
#endif // QT_CONFIG(accessibility)
#if QT_CONFIG(accessibility)
        secretEdit->setAccessibleDescription(QCoreApplication::translate("MainWindow", "Note: 2nd factors aren't protected against physical attacks. Change all OTP secrets in case you loose the Nitrokey.", nullptr));
#endif // QT_CONFIG(accessibility)
        secretEdit->setInputMask(QString());
        secretEdit->setText(QString());
        secretEdit->setPlaceholderText(QCoreApplication::translate("MainWindow", "********************************", nullptr));
        labelNotify->setText(QCoreApplication::translate("MainWindow", "Secret copied to clipboard", nullptr));
#if QT_CONFIG(tooltip)
        checkBox->setToolTip(QCoreApplication::translate("MainWindow", "<html><head/><body><p>Hide or show the secret.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBox->setText(QCoreApplication::translate("MainWindow", "Hide secret", nullptr));
        label_7->setText(QCoreApplication::translate("MainWindow", "Generated secret target length (bytes):", nullptr));
#if QT_CONFIG(accessibility)
        secret_key_generated_len->setAccessibleName(QCoreApplication::translate("MainWindow", "TOTP interval value", nullptr));
#endif // QT_CONFIG(accessibility)
#if QT_CONFIG(tooltip)
        randomSecretButton->setToolTip(QCoreApplication::translate("MainWindow", "After generating a random secret, you would need to copy it into your application or service where you want to login to.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(accessibility)
        randomSecretButton->setAccessibleDescription(QString());
#endif // QT_CONFIG(accessibility)
        randomSecretButton->setText(QCoreApplication::translate("MainWindow", "Generate random secret", nullptr));
#if QT_CONFIG(tooltip)
        btn_copyToClipboard->setToolTip(QCoreApplication::translate("MainWindow", "Copy secret to clipboard", nullptr));
#endif // QT_CONFIG(tooltip)
        btn_copyToClipboard->setText(QCoreApplication::translate("MainWindow", "Copy to clipboard", nullptr));
        label_26->setText(QCoreApplication::translate("MainWindow", "Note: 2<sup>nd</sup> factors aren't protected against physical attacks. Change all OTP secrets in case you loose the Nitrokey.", nullptr));
        label_22->setText(QCoreApplication::translate("MainWindow", "Parameters", nullptr));
#if QT_CONFIG(accessibility)
        counterEdit->setAccessibleName(QCoreApplication::translate("MainWindow", "HOTP moving factor seed", nullptr));
#endif // QT_CONFIG(accessibility)
        counterEdit->setInputMask(QString());
        counterEdit->setText(QCoreApplication::translate("MainWindow", "00000000000000000000", nullptr));
#if QT_CONFIG(accessibility)
        setToZeroButton->setAccessibleName(QCoreApplication::translate("MainWindow", "Set HOTP counter to zero", nullptr));
#endif // QT_CONFIG(accessibility)
        setToZeroButton->setText(QCoreApplication::translate("MainWindow", "Set to zero", nullptr));
#if QT_CONFIG(accessibility)
        setToRandomButton->setAccessibleName(QCoreApplication::translate("MainWindow", "Set HOTP counter to random value", nullptr));
#endif // QT_CONFIG(accessibility)
        setToRandomButton->setText(QCoreApplication::translate("MainWindow", "Set to random", nullptr));
#if QT_CONFIG(accessibility)
        digits6radioButton->setAccessibleName(QCoreApplication::translate("MainWindow", "OTP code length: 6 digits", nullptr));
#endif // QT_CONFIG(accessibility)
        digits6radioButton->setText(QCoreApplication::translate("MainWindow", "6 digits", nullptr));
#if QT_CONFIG(accessibility)
        digits8radioButton->setAccessibleName(QCoreApplication::translate("MainWindow", "OTP code length:  8 digits", nullptr));
#endif // QT_CONFIG(accessibility)
        digits8radioButton->setText(QCoreApplication::translate("MainWindow", "8 digits", nullptr));
#if QT_CONFIG(accessibility)
        intervalSpinBox->setAccessibleName(QCoreApplication::translate("MainWindow", "TOTP interval value", nullptr));
#endif // QT_CONFIG(accessibility)
        label_6->setText(QCoreApplication::translate("MainWindow", "Moving factor seed:", nullptr));
        label_5->setText(QCoreApplication::translate("MainWindow", "HOTP length:", nullptr));
        intervalLabel->setText(QCoreApplication::translate("MainWindow", "TOTP interval:", nullptr));
#if QT_CONFIG(tooltip)
        cancelButton->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        cancelButton->setText(QCoreApplication::translate("MainWindow", "Cancel", nullptr));
        writeButton->setText(QCoreApplication::translate("MainWindow", "Save", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("MainWindow", "OTP Slot Configuration", nullptr));
        label_11->setText(QCoreApplication::translate("MainWindow", "OTP Password settings", nullptr));
        enableUserPasswordCheckBox->setText(QCoreApplication::translate("MainWindow", "Protect OTP by user PIN (will be requested on first use each session)", nullptr));
        deleteUserPasswordCheckBox->setText(QCoreApplication::translate("MainWindow", "Forget user PIN after 10 minutes (if unchecked user PIN will remain in memory until application exits)", nullptr));
        generalCancelButton->setText(QCoreApplication::translate("MainWindow", "Cancel", nullptr));
        writeGeneralConfigButton->setText(QCoreApplication::translate("MainWindow", "Save", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QCoreApplication::translate("MainWindow", "OTP General", nullptr));
#if QT_CONFIG(accessibility)
        PWS_EditPassword->setAccessibleName(QCoreApplication::translate("MainWindow", "Password:", nullptr));
#endif // QT_CONFIG(accessibility)
#if QT_CONFIG(accessibility)
        PWS_EditLoginName->setAccessibleName(QCoreApplication::translate("MainWindow", "Login name:", nullptr));
#endif // QT_CONFIG(accessibility)
        label_19->setText(QCoreApplication::translate("MainWindow", "Password:", nullptr));
#if QT_CONFIG(accessibility)
        PWS_EditSlotName->setAccessibleName(QCoreApplication::translate("MainWindow", "Slot name:", nullptr));
#endif // QT_CONFIG(accessibility)
        label_18->setText(QCoreApplication::translate("MainWindow", "Login name:", nullptr));
#if QT_CONFIG(accessibility)
        PWS_ButtonClearSlot->setAccessibleName(QCoreApplication::translate("MainWindow", "Erase Password Safe slot", nullptr));
#endif // QT_CONFIG(accessibility)
        PWS_ButtonClearSlot->setText(QCoreApplication::translate("MainWindow", "Erase Slot", nullptr));
        label_17->setText(QCoreApplication::translate("MainWindow", "Slot name:", nullptr));
        PWS_ComboBoxSelectSlot->setItemText(0, QCoreApplication::translate("MainWindow", "Static password 0", nullptr));

#if QT_CONFIG(accessibility)
        PWS_ComboBoxSelectSlot->setAccessibleName(QCoreApplication::translate("MainWindow", "Password Safe slot number", nullptr));
#endif // QT_CONFIG(accessibility)
#if QT_CONFIG(accessibility)
        PWS_ButtonCreatePW->setAccessibleDescription(QString());
#endif // QT_CONFIG(accessibility)
        PWS_ButtonCreatePW->setText(QCoreApplication::translate("MainWindow", "Generate random password", nullptr));
        label_16->setText(QCoreApplication::translate("MainWindow", "Slot:", nullptr));
#if QT_CONFIG(accessibility)
        PWS_CheckBoxHideSecret->setAccessibleName(QString());
#endif // QT_CONFIG(accessibility)
        PWS_CheckBoxHideSecret->setText(QCoreApplication::translate("MainWindow", "Hide secret", nullptr));
        l_chars_left_info->setText(QCoreApplication::translate("MainWindow", "Characters left:", nullptr));
        l_c_password->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
        l_utf8_info->setText(QCoreApplication::translate("MainWindow", "<html><head/><body><p>Password Safe fields support UTF8 data. It means that you can use your national characters here. Please remember however that non-English characters could take more space (up to 4 characters). The counters next to each field are to inform how much more standard English characters can given field accept.</p></body></html>", nullptr));
        PWS_ButtonEnable->setText(QCoreApplication::translate("MainWindow", "Unlock Password Safe", nullptr));
        PWS_Lock->setText(QCoreApplication::translate("MainWindow", "Lock Device", nullptr));
        PWS_ButtonClose->setText(QCoreApplication::translate("MainWindow", "Cancel", nullptr));
        PWS_ButtonSaveSlot->setText(QCoreApplication::translate("MainWindow", "Save", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), QCoreApplication::translate("MainWindow", "Password Safe", nullptr));
        gr_general->setTitle(QCoreApplication::translate("MainWindow", "General", nullptr));
        cb_first_run_message->setText(QCoreApplication::translate("MainWindow", "Show first-run message", nullptr));
        cb_show_window_on_start->setText(QCoreApplication::translate("MainWindow", "Show main window on start", nullptr));
        cb_hide_main_window_on_close->setText(QCoreApplication::translate("MainWindow", "Do not quit when the main window is closed", nullptr));
        cb_hide_main_window_on_connection->setText(QCoreApplication::translate("MainWindow", "Hide main window when device disconnects", nullptr));
        cb_show_main_window_on_connection->setText(QCoreApplication::translate("MainWindow", "Show main window when device connects", nullptr));
        cb_check_symlink->setText(QCoreApplication::translate("MainWindow", "Show warning when no partitions could be detected on Encrypted Volume (Linux only)", nullptr));
        cb_device_connection_message->setText(QCoreApplication::translate("MainWindow", "Show message about device's connection / disconnection", nullptr));
        label_28->setText(QCoreApplication::translate("MainWindow", "<html><head/><body><p>Translation file (needs restart)</p></body></html>", nullptr));
#if QT_CONFIG(accessibility)
        combo_languages->setAccessibleName(QCoreApplication::translate("MainWindow", "Translation file (needs restart)", nullptr));
#endif // QT_CONFIG(accessibility)
        groupBox->setTitle(QCoreApplication::translate("MainWindow", "Debug log settings", nullptr));
#if QT_CONFIG(accessibility)
        edit_debug_file_path->setAccessibleName(QCoreApplication::translate("MainWindow", "Path for debug log file:", nullptr));
#endif // QT_CONFIG(accessibility)
#if QT_CONFIG(accessibility)
        spin_debug_verbosity->setAccessibleName(QCoreApplication::translate("MainWindow", "Verbosity level:", nullptr));
#endif // QT_CONFIG(accessibility)
        label_10->setText(QCoreApplication::translate("MainWindow", "Path for debug log file:", nullptr));
        label_20->setText(QCoreApplication::translate("MainWindow", "Verbosity level:", nullptr));
#if QT_CONFIG(accessibility)
        cb_debug_enabled->setAccessibleName(QString());
#endif // QT_CONFIG(accessibility)
        cb_debug_enabled->setText(QCoreApplication::translate("MainWindow", "Logging enabled", nullptr));
        btn_select_debug_console->setText(QCoreApplication::translate("MainWindow", "Log to console", nullptr));
        btn_select_debug_file_path->setText(QCoreApplication::translate("MainWindow", "Select path", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("MainWindow", "Clipboard settings", nullptr));
#if QT_CONFIG(accessibility)
        spin_OTP_time->setAccessibleName(QCoreApplication::translate("MainWindow", "Time to store OTP secrets in clipboard (in seconds):", nullptr));
#endif // QT_CONFIG(accessibility)
        label_30->setText(QCoreApplication::translate("MainWindow", "Time to store Password Safe secrets in clipboard (in seconds):", nullptr));
#if QT_CONFIG(accessibility)
        spin_PWS_time->setAccessibleName(QCoreApplication::translate("MainWindow", "TIme to store Password Safe secrets in clipboard (in seconds):", nullptr));
#endif // QT_CONFIG(accessibility)
        label_31->setText(QCoreApplication::translate("MainWindow", "Time to store OTP secrets in clipboard (in seconds):", nullptr));
        btn_cancelSettings->setText(QCoreApplication::translate("MainWindow", "Cancel", nullptr));
        btn_writeSettings->setText(QCoreApplication::translate("MainWindow", "Save", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_4), QCoreApplication::translate("MainWindow", "Settings", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MainWindow: public Ui_MainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAINWINDOW_H
