/****************************************************************************
** Meta object code from reading C++ file 'stick20hiddenvolumedialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.14)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../src/ui/stick20hiddenvolumedialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'stick20hiddenvolumedialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.14. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_stick20HiddenVolumeDialog_t {
    QByteArrayData data[15];
    char stringdata0[265];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_stick20HiddenVolumeDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_stick20HiddenVolumeDialog_t qt_meta_stringdata_stick20HiddenVolumeDialog = {
    {
QT_MOC_LITERAL(0, 0, 25), // "stick20HiddenVolumeDialog"
QT_MOC_LITERAL(1, 26, 31), // "on_ShowPasswordCheckBox_toggled"
QT_MOC_LITERAL(2, 58, 0), // ""
QT_MOC_LITERAL(3, 59, 7), // "checked"
QT_MOC_LITERAL(4, 67, 20), // "on_buttonBox_clicked"
QT_MOC_LITERAL(5, 88, 16), // "QAbstractButton*"
QT_MOC_LITERAL(6, 105, 6), // "button"
QT_MOC_LITERAL(7, 112, 29), // "on_HVPasswordEdit_textChanged"
QT_MOC_LITERAL(8, 142, 4), // "arg1"
QT_MOC_LITERAL(9, 147, 21), // "on_rd_percent_clicked"
QT_MOC_LITERAL(10, 169, 16), // "on_rd_MB_clicked"
QT_MOC_LITERAL(11, 186, 16), // "on_rd_GB_clicked"
QT_MOC_LITERAL(12, 203, 30), // "on_StartBlockSpin_valueChanged"
QT_MOC_LITERAL(13, 234, 1), // "i"
QT_MOC_LITERAL(14, 236, 28) // "on_EndBlockSpin_valueChanged"

    },
    "stick20HiddenVolumeDialog\0"
    "on_ShowPasswordCheckBox_toggled\0\0"
    "checked\0on_buttonBox_clicked\0"
    "QAbstractButton*\0button\0"
    "on_HVPasswordEdit_textChanged\0arg1\0"
    "on_rd_percent_clicked\0on_rd_MB_clicked\0"
    "on_rd_GB_clicked\0on_StartBlockSpin_valueChanged\0"
    "i\0on_EndBlockSpin_valueChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_stick20HiddenVolumeDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x08 /* Private */,
       4,    1,   57,    2, 0x08 /* Private */,
       7,    1,   60,    2, 0x08 /* Private */,
       9,    0,   63,    2, 0x08 /* Private */,
      10,    0,   64,    2, 0x08 /* Private */,
      11,    0,   65,    2, 0x08 /* Private */,
      12,    1,   66,    2, 0x08 /* Private */,
      14,    1,   69,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Double,   13,
    QMetaType::Void, QMetaType::Double,   13,

       0        // eod
};

void stick20HiddenVolumeDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<stick20HiddenVolumeDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_ShowPasswordCheckBox_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->on_buttonBox_clicked((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
        case 2: _t->on_HVPasswordEdit_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->on_rd_percent_clicked(); break;
        case 4: _t->on_rd_MB_clicked(); break;
        case 5: _t->on_rd_GB_clicked(); break;
        case 6: _t->on_StartBlockSpin_valueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 7: _t->on_EndBlockSpin_valueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractButton* >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject stick20HiddenVolumeDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_stick20HiddenVolumeDialog.data,
    qt_meta_data_stick20HiddenVolumeDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *stick20HiddenVolumeDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *stick20HiddenVolumeDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_stick20HiddenVolumeDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int stick20HiddenVolumeDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
